searchData={"items":[{"type":"module","title":"Unicode","doc":"Functions to introspect the Unicode character database and\nto provide fast codepoint lookups for scripts, blocks,\ncategories and properties.","ref":"Unicode.html"},{"type":"function","title":"Unicode.all/0","doc":"Returns a list of tuples representing the\nfull range of Unicode code points.","ref":"Unicode.html#all/0"},{"type":"function","title":"Unicode.alphabetic?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters in the\ngiven string) adhere to the Derived Core Property `Alphabetic`\notherwise returns `false`.\n\nThese are all characters that are usually used as representations\nof letters/syllabes in words/sentences.","ref":"Unicode.html#alphabetic?/1"},{"type":"function","title":"Arguments - Unicode.alphabetic?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#alphabetic?/1-arguments"},{"type":"function","title":"Returns - Unicode.alphabetic?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#alphabetic?/1-returns"},{"type":"function","title":"Examples - Unicode.alphabetic?/1","doc":"iex> Unicode.alphabetic?(?a)\n    true\n\n    iex> Unicode.alphabetic?(\"A\")\n    true\n\n    iex> Unicode.alphabetic?(\"Elixir\")\n    true\n\n    iex> Unicode.alphabetic?(\"الإكسير\")\n    true\n\n    # comma and whitespace\n    iex> Unicode.alphabetic?(\"foo, bar\")\n    false\n\n    iex> Unicode.alphabetic?(\"42\")\n    false\n\n    iex> Unicode.alphabetic?(\"龍王\")\n    true\n\n    # Summation, ∑\n    iex> Unicode.alphabetic?(\"∑\")\n    false\n\n    # Greek capital letter sigma, Σ\n    iex> Unicode.alphabetic?(\"Σ\")\n    true","ref":"Unicode.html#alphabetic?/1-examples"},{"type":"function","title":"Unicode.alphanumeric?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) are either `alphabetic?/1` or\n`numeric?/1` otherwise returns `false`.","ref":"Unicode.html#alphanumeric?/1"},{"type":"function","title":"Arguments - Unicode.alphanumeric?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#alphanumeric?/1-arguments"},{"type":"function","title":"Returns - Unicode.alphanumeric?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#alphanumeric?/1-returns"},{"type":"function","title":"Examples - Unicode.alphanumeric?/1","doc":"iex> Unicode.alphanumeric? \"1234\"\n    true\n\n    iex> Unicode.alphanumeric? \"KeyserSöze1995\"\n    true\n\n    iex> Unicode.alphanumeric? \"3段\"\n    true\n\n    iex> Unicode.alphanumeric? \"dragon@example.com\"\n    false","ref":"Unicode.html#alphanumeric?/1-examples"},{"type":"function","title":"Unicode.assigned/0","doc":"Returns a list of tuples representing the\nassigned ranges of Unicode code points.\n\nThis information is derived from the block\nranges as defined by `Unicode.Block.blocks/0`.","ref":"Unicode.html#assigned/0"},{"type":"function","title":"Unicode.block/1","doc":"Returns the block name of a codepoint\nor the list of block names for each codepoint\nin a string.","ref":"Unicode.html#block/1"},{"type":"function","title":"Arguments - Unicode.block/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#block/1-arguments"},{"type":"function","title":"Returns - Unicode.block/1","doc":"* in the case of a single codepoint, an atom\n  block name\n\n* in the case of a string, a list of atom\n  block names for each codepoint in the\n `codepoint_or_string`","ref":"Unicode.html#block/1-returns"},{"type":"function","title":"Exmaples - Unicode.block/1","doc":"iex> Unicode.block ?ä\n    :latin_1_supplement\n\n    iex> Unicode.block ?A\n    :basic_latin\n\n    iex> Unicode.block \"äA\"\n    [:latin_1_supplement, :basic_latin]","ref":"Unicode.html#block/1-exmaples"},{"type":"function","title":"Unicode.cased?/1","doc":"Returns either `true` if the codepoint has the `:cased` property\nor `false`.\n\nThe `:cased` property means that this character has at least\nan upper and lower representation and possibly a titlecase\nrepresentation too.","ref":"Unicode.html#cased?/1"},{"type":"function","title":"Arguments - Unicode.cased?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#cased?/1-arguments"},{"type":"function","title":"Returns - Unicode.cased?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#cased?/1-returns"},{"type":"function","title":"Examples - Unicode.cased?/1","doc":"iex> Unicode.cased? ?ယ\n    false\n\n    iex> Unicode.cased? ?A\n    true","ref":"Unicode.html#cased?/1-examples"},{"type":"function","title":"Unicode.category/1","doc":"Returns the Unicode category for a codepoint or a list of\ncategories for a string.","ref":"Unicode.html#category/1"},{"type":"function","title":"Argument - Unicode.category/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#category/1-argument"},{"type":"function","title":"Returns - Unicode.category/1","doc":"* in the case of a single codepoint, an atom representing\n  one of the categories listed below\n\n* in the case of a string, a list representing the\n  category for each codepoint in the string","ref":"Unicode.html#category/1-returns"},{"type":"function","title":"Notes - Unicode.category/1","doc":"THese categories match the names of the Unicode character\nclasses used in various regular expression engines and in\nUnicode Sets.  The full list of categories is:\n\n| Category\t| Matches\t                |\n| --------- | ----------------------- |\n| :C\t      | Other\t                  |\n| :Cc\t      | Control\t                |\n| :Cf\t      | Format\t                |\n| :Cn\t      | Unassigned\t            |\n| :Co\t      | Private use\t            |\n| :Cs\t      | Surrogate\t              |\n| :L\t      | Letter\t                |\n| :Ll\t      | Lower case letter\t      |\n| :Lm\t      | Modifier letter\t        |\n| :Lo\t      | Other letter\t          |\n| :Lt\t      | Title case letter\t      |\n| :Lu\t      | Upper case letter\t      |\n| :M\t      | Mark\t                  |\n| :Mc\t      | Spacing mark\t          |\n| :Me\t      | Enclosing mark\t        |\n| :Mn\t      | Non-spacing mark\t      |\n| :N\t      | Number\t                |\n| :Nd\t      | Decimal number\t        |\n| :Nl\t      | Letter number\t          |\n| :No\t      | Other number\t          |\n| :P\t      | Punctuation\t            |\n| :Pc\t      | Connector punctuation\t  |\n| :Pd\t      | Dash punctuation\t      |\n| :Pe\t      | Close punctuation\t      |\n| :Pf\t      | Final punctuation\t      |\n| :Pi\t      | Initial punctuation\t    |\n| :Po\t      | Other punctuation\t      |\n| :Ps\t      | Open punctuation\t      |\n| :S\t      | Symbol\t                |\n| :Sc\t      | Currency symbol\t        |\n| :Sk\t      | Modifier symbol\t        |\n| :Sm\t      | Mathematical symbol\t    |\n| :So\t      | Other symbol\t          |\n| :Z\t      | Separator\t              |\n| :Zl\t      | Line separator\t        |\n| :Zp\t      | Paragraph separator\t    |\n| :Zs\t      | Space separator\t        |\n\nNote too that the group level categories like `:L`,\n`:M`, `:S` and so on are not assigned to any codepoint.\nThey can only be identified by combining the results\nfor each of the subsidiary categories.","ref":"Unicode.html#category/1-notes"},{"type":"function","title":"Examples - Unicode.category/1","doc":"iex> Unicode.category ?ä\n    :Ll\n\n    iex> Unicode.category ?A\n    :Lu\n\n    iex> Unicode.category ?🧐\n    :So\n\n    iex> Unicode.category ?+\n    :Sm\n\n    iex> Unicode.category ?1\n    :Nd\n\n    iex> Unicode.category \"äA\"\n    [:Ll, :Lu]","ref":"Unicode.html#category/1-examples"},{"type":"function","title":"Unicode.digits?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) adhere to Unicode category `:Nd`\notherwise returns `false`.\n\nThis group of characters represents the decimal digits zero\nthrough nine (0..9) and the equivalents in non-Latin scripts.","ref":"Unicode.html#digits?/1"},{"type":"function","title":"Arguments - Unicode.digits?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#digits?/1-arguments"},{"type":"function","title":"Returns - Unicode.digits?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#digits?/1-returns"},{"type":"function","title":"Examples - Unicode.digits?/1","doc":"","ref":"Unicode.html#digits?/1-examples"},{"type":"function","title":"Unicode.downcase?/1","doc":"","ref":"Unicode.html#downcase?/1"},{"type":"function","title":"Unicode.emoji?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) are `emoji` otherwise returns `false`.","ref":"Unicode.html#emoji?/1"},{"type":"function","title":"Arguments - Unicode.emoji?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#emoji?/1-arguments"},{"type":"function","title":"Returns - Unicode.emoji?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#emoji?/1-returns"},{"type":"function","title":"Examples - Unicode.emoji?/1","doc":"iex> Unicode.emoji? \"🧐🤓🤩🤩️🤯\"\n    true","ref":"Unicode.html#emoji?/1-examples"},{"type":"function","title":"Unicode.lowercase?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) the category `:Ll` otherwise returns `false`.\n\nNotice that there are many languages that do not have a distinction\nbetween cases. Their characters are not included in this group.","ref":"Unicode.html#lowercase?/1"},{"type":"function","title":"Arguments - Unicode.lowercase?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#lowercase?/1-arguments"},{"type":"function","title":"Returns - Unicode.lowercase?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#lowercase?/1-returns"},{"type":"function","title":"Examples - Unicode.lowercase?/1","doc":"iex> Unicode.lowercase?(?a)\n    true\n\n    iex> Unicode.lowercase?(\"A\")\n    false\n\n    iex> Unicode.lowercase?(\"Elixir\")\n    false\n\n    iex> Unicode.lowercase?(\"léon\")\n    true\n\n    iex> Unicode.lowercase?(\"foo, bar\")\n    false\n\n    iex> Unicode.lowercase?(\"42\")\n    false\n\n    iex> Unicode.lowercase?(\"Σ\")\n    false\n\n    iex> Unicode.lowercase?(\"σ\")\n    true","ref":"Unicode.html#lowercase?/1-examples"},{"type":"function","title":"Unicode.math?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) the category `:Sm` otherwise returns `false`.\n\nThese are all characters whose primary usage is in mathematical\nconcepts (and not in alphabets). Notice that the numerical digits\nare not part of this group.","ref":"Unicode.html#math?/1"},{"type":"function","title":"Arguments - Unicode.math?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#math?/1-arguments"},{"type":"function","title":"Returns - Unicode.math?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#math?/1-returns"},{"type":"function","title":"Examples - Unicode.math?/1","doc":"iex> Unicode.math?(?=)\n    true\n\n    iex> Unicode.math?(\"=\")\n    true\n\n    iex> Unicode.math?(\"1+1=2\") # Digits do not have the `:math` property.\n    false\n\n    iex> Unicode.math?(\"परिस\")\n    false\n\n    iex> Unicode.math?(\"∑\") # Summation, \\u2211\n    true\n\n    iex> Unicode.math?(\"Σ\") # Greek capital letter sigma, \\u03a3\n    false","ref":"Unicode.html#math?/1-examples"},{"type":"function","title":"Unicode.numeric?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) adhere to Unicode categories `:Nd`,\n`:Nl` and `:No` otherwise returns `false`.\n\nThis group of characters represents the decimal digits zero\nthrough nine (0..9) and the equivalents in non-Latin scripts.","ref":"Unicode.html#numeric?/1"},{"type":"function","title":"Arguments - Unicode.numeric?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#numeric?/1-arguments"},{"type":"function","title":"Returns - Unicode.numeric?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#numeric?/1-returns"},{"type":"function","title":"Examples - Unicode.numeric?/1","doc":"iex> Unicode.numeric?(\"65535\")\n    true\n\n    iex> Unicode.numeric?(\"42\")\n    true\n\n    iex> Unicode.numeric?(\"lapis philosophorum\")\n    false","ref":"Unicode.html#numeric?/1-examples"},{"type":"function","title":"Unicode.properties/1","doc":"Returns the list of properties of each codepoint\nin a given string or the list of properties for a\ngiven string.","ref":"Unicode.html#properties/1"},{"type":"function","title":"Arguments - Unicode.properties/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#properties/1-arguments"},{"type":"function","title":"Returns - Unicode.properties/1","doc":"* in the case of a single codepoint, an atom\n  list of properties.\n\n* in the case of a string, one atom list for each\n  codepoint in the `codepoint_or_string`.","ref":"Unicode.html#properties/1-returns"},{"type":"function","title":"Exmaples - Unicode.properties/1","doc":"iex> Unicode.properties 0x1bf0\n    [\n      :alphabetic,\n      :case_ignorable,\n      :grapheme_extend,\n      :id_continue,\n      :incb,\n      :other_alphabetic,\n      :xid_continue\n    ]\n\n    iex> Unicode.properties ?A\n    [\n      :alphabetic,\n      :ascii_hex_digit,\n      :cased,\n      :changes_when_casefolded,\n      :changes_when_casemapped,\n      :changes_when_lowercased,\n      :grapheme_base,\n      :hex_digit,\n      :id_continue,\n      :id_start,\n      :uppercase,\n      :xid_continue,\n      :xid_start\n    ]\n\n    iex> Unicode.properties ?+\n    [:grapheme_base, :math, :pattern_syntax]\n\n    iex> Unicode.properties \"a1+\"\n    [\n      [\n        :alphabetic,\n        :ascii_hex_digit,\n        :cased,\n        :changes_when_casemapped,\n        :changes_when_titlecased,\n        :changes_when_uppercased,\n        :grapheme_base,\n        :hex_digit,\n        :id_continue,\n        :id_start,\n        :lowercase,\n        :xid_continue,\n        :xid_start\n      ],\n      [\n        :ascii_hex_digit,\n        :emoji,\n        :emoji_component,\n        :grapheme_base,\n        :hex_digit,\n        :id_continue,\n        :xid_continue\n      ],\n      [\n        :grapheme_base,\n        :math,\n        :pattern_syntax\n      ]\n    ]","ref":"Unicode.html#properties/1-exmaples"},{"type":"function","title":"Unicode.property_servers/0","doc":"Returns a map of aliases mapping\nproperty names to a module that\nserves that property.","ref":"Unicode.html#property_servers/0"},{"type":"function","title":"Unicode.ranges/0","doc":"","ref":"Unicode.html#ranges/0"},{"type":"function","title":"Unicode.replace_invalid/3","doc":"Ensures that a binary is valid UTF encoded.\n\nThe string is validated by replacing any invalid UTF\nbytes or incomplete sequences with a replacement string.","ref":"Unicode.html#replace_invalid/3"},{"type":"function","title":"Arguments - Unicode.replace_invalid/3","doc":"* `binary` is any sequence of bytes.\n\n* `encoding` is any UTF encoding being one of\n  `:utf8`, `:utf16`, `:utf16be`, `:utf16le`, `:utf32`, `:utf32be` or\n  `:utf32le`. The default is `:utf8`.\n\n* `replacement` is any string that will be used to replace\n  invalid UTF-8 bytes or incomplete sequences. The default\n  is `\"�\"`.","ref":"Unicode.html#replace_invalid/3-arguments"},{"type":"function","title":"Returns - Unicode.replace_invalid/3","doc":"* A valid UTF binary that may or may not include\n  replacements for invalid UTF. If `encoding` is `:utf8`\n  then the return type is a `t:String.t/0`.","ref":"Unicode.html#replace_invalid/3-returns"},{"type":"function","title":"Notes - Unicode.replace_invalid/3","doc":"* `Unicode.replace_invalid(string, :utf8)` will delegate to\n  `String.replace_invalid/2` where available, which is from\n  Elixir 1.16 onwards.","ref":"Unicode.html#replace_invalid/3-notes"},{"type":"function","title":"Example - Unicode.replace_invalid/3","doc":"iex> Unicode.replace_invalid(<<\"foo\", 0b11111111, \"bar\">>, :utf8)\n    \"foo�bar\"","ref":"Unicode.html#replace_invalid/3-example"},{"type":"function","title":"Unicode.script/1","doc":"Returns the script name of a codepoint\nor the list of block names for each codepoint\nin a string.","ref":"Unicode.html#script/1"},{"type":"function","title":"Arguments - Unicode.script/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#script/1-arguments"},{"type":"function","title":"Returns - Unicode.script/1","doc":"* in the case of a single codepoint, a string\n  script name\n\n* in the case of a string, a list of string\n  script names for each codepoint in the\n` codepoint_or_string`","ref":"Unicode.html#script/1-returns"},{"type":"function","title":"Exmaples - Unicode.script/1","doc":"iex> Unicode.script ?ä\n    :latin\n\n    iex> Unicode.script ?خ\n    :arabic\n\n    iex> Unicode.script ?अ\n    :devanagari\n\n    iex> Unicode.script ?א\n    :hebrew\n\n    iex> Unicode.script ?Ж\n    :cyrillic\n\n    iex> Unicode.script ?δ\n    :greek\n\n    iex> Unicode.script ?ก\n    :thai\n\n    iex> Unicode.script ?ယ\n    :myanmar","ref":"Unicode.html#script/1-exmaples"},{"type":"function","title":"Unicode.script_dominance/1","doc":"Returns a keyword list of scripts in descending dominance\norder for a given string.\n\nDominance is determined by (in order of priority):\n\n* Index of the first occurrence of the script\n* Count of the number of graphemes in the script\n* Lexical ordering of the script name (used as a final means\n  to ensure returning a deterministic result).","ref":"Unicode.html#script_dominance/1"},{"type":"function","title":"Arguments - Unicode.script_dominance/1","doc":"* `string` is any `t:String.t/0`.","ref":"Unicode.html#script_dominance/1-arguments"},{"type":"function","title":"Returns - Unicode.script_dominance/1","doc":"* A keyword list where the key is a `t:script/0` and the value\n  is a tuple where the first element is the index in the\n  string where that script first appeared and the second\n  element is the number of graphemes in that script. The list\n  is ordered by descending dominance.","ref":"Unicode.html#script_dominance/1-returns"},{"type":"function","title":"Example - Unicode.script_dominance/1","doc":"iex> Unicode.script_dominance \"Tokyo is the capital of 日本\"\n    [latin: {0, 19}, common: {5, 5}, han: {24, 2}]\n\n    iex> Unicode.script_dominance \"おはよう\"\n    [hiragana: {0, 4}]","ref":"Unicode.html#script_dominance/1-example"},{"type":"function","title":"Unicode.script_statistic/1","doc":"Returns the first index and grapheme count of each\nscript detected in a string.","ref":"Unicode.html#script_statistic/1"},{"type":"function","title":"Arguments - Unicode.script_statistic/1","doc":"* `string` is any `t:String.t/0`.","ref":"Unicode.html#script_statistic/1-arguments"},{"type":"function","title":"Returns - Unicode.script_statistic/1","doc":"* A map where the key is a `t:script/0` and the value\n  is a tuple where the first element is the index in the\n  string where that script first appeared and the second\n  element is the number of graphemes in that script.","ref":"Unicode.html#script_statistic/1-returns"},{"type":"function","title":"Examples - Unicode.script_statistic/1","doc":"iex> Unicode.script_statistic \"Tokyo is the capital of 日本\"\n    %{common: {5, 5}, han: {24, 2}, latin: {0, 19}}\n\n    iex> Unicode.script_statistic \"おはよう\"\n    %{hiragana: {0, 4}}","ref":"Unicode.html#script_statistic/1-examples"},{"type":"function","title":"Unicode.unaccent/1","doc":"Removes accents (diacritical marks) from\na string.","ref":"Unicode.html#unaccent/1"},{"type":"function","title":"Arguments - Unicode.unaccent/1","doc":"* `string` is any `t:String.t/0`","ref":"Unicode.html#unaccent/1-arguments"},{"type":"function","title":"Returns - Unicode.unaccent/1","doc":"* A string with all diacritical marks\n  removed","ref":"Unicode.html#unaccent/1-returns"},{"type":"function","title":"Notes - Unicode.unaccent/1","doc":"The string is first normalised to `:nfd` form\nand then all characters in the block\n`:comnbining_diacritical_marks` is removed\nfrom the string","ref":"Unicode.html#unaccent/1-notes"},{"type":"function","title":"Example - Unicode.unaccent/1","doc":"iex> Unicode.unaccent(\"Et Ça sera sa moitié.\")\n    \"Et Ca sera sa moitie.\"","ref":"Unicode.html#unaccent/1-example"},{"type":"function","title":"Unicode.upcase?/1","doc":"","ref":"Unicode.html#upcase?/1"},{"type":"function","title":"Unicode.uppercase?/1","doc":"Returns `true` if a single Unicode codepoint (or all characters\nin the given string) the category `:Lu` otherwise returns `false`.\n\nNotice that there are many languages that do not have a distinction\nbetween cases. Their characters are not included in this group.","ref":"Unicode.html#uppercase?/1"},{"type":"function","title":"Arguments - Unicode.uppercase?/1","doc":"* `codepoint_or_string` is a single integer codepoint\n  or a `t:String.t/0`.","ref":"Unicode.html#uppercase?/1-arguments"},{"type":"function","title":"Returns - Unicode.uppercase?/1","doc":"* `true` or `false`\n\nFor the string-version, the result will be true only if _all_\ncodepoints in the string adhere to the property.","ref":"Unicode.html#uppercase?/1-returns"},{"type":"function","title":"Examples - Unicode.uppercase?/1","doc":"iex> Unicode.uppercase?(?a)\n    false\n\n    iex> Unicode.uppercase?(\"A\")\n    true\n\n    iex> Unicode.uppercase?(\"Elixir\")\n    false\n\n    iex> Unicode.uppercase?(\"CAMEMBERT\")\n    true\n\n    iex> Unicode.uppercase?(\"foo, bar\")\n    false\n\n    iex> Unicode.uppercase?(\"42\")\n    false\n\n    iex> Unicode.uppercase?(\"Σ\")\n    true\n\n    iex> Unicode.uppercase?(\"σ\")\n    false","ref":"Unicode.html#uppercase?/1-examples"},{"type":"function","title":"Unicode.version/0","doc":"Returns the version of Unicode in use.","ref":"Unicode.html#version/0"},{"type":"type","title":"Unicode.codepoint/0","doc":"A codepoint is an integer representing a Unicode character","ref":"Unicode.html#t:codepoint/0"},{"type":"type","title":"Unicode.codepoint_or_string/0","doc":"A codepoint or a string","ref":"Unicode.html#t:codepoint_or_string/0"},{"type":"type","title":"Unicode.encoding/0","doc":"Unicode UTF encodings","ref":"Unicode.html#t:encoding/0"},{"type":"type","title":"Unicode.script/0","doc":"The valid scripts as of Unicode 15","ref":"Unicode.html#t:script/0"},{"type":"module","title":"Unicode.Block","doc":"Functions to introspect Unicode\nblocks for binaries\n(Strings) and codepoints.","ref":"Unicode.Block.html"},{"type":"function","title":"Unicode.Block.aliases/0","doc":"Returns a map of aliases for\nUnicode blocks.\n\nAn alias is an alternative name\nfor referring to a block. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.Block.html#aliases/0"},{"type":"function","title":"Unicode.Block.assigned/0","doc":"Returns a list of tuples representing the\nassigned ranges of all Unicode code points.","ref":"Unicode.Block.html#assigned/0"},{"type":"function","title":"Unicode.Block.block/1","doc":"Returns the block name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nblock name is returned.\n\nFor a binary a list of distinct block\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.Block.html#block/1"},{"type":"function","title":"Unicode.Block.blocks/0","doc":"Returns the map of Unicode\nblocks.\n\nThe block name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.Block.html#blocks/0"},{"type":"function","title":"Unicode.Block.count/1","doc":"Returns the count of the number of characters\nfor a given block.\n\nAliases are resolved by this function.","ref":"Unicode.Block.html#count/1"},{"type":"function","title":"Example - Unicode.Block.count/1","doc":"iex> Unicode.Block.count(:old_north_arabian)\n    32","ref":"Unicode.Block.html#count/1-example"},{"type":"function","title":"Unicode.Block.fetch/1","doc":"Returns the Unicode ranges for\na given block as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.Block.html#fetch/1"},{"type":"function","title":"Unicode.Block.get/1","doc":"Returns the Unicode ranges for\na given block as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.Block.html#get/1"},{"type":"function","title":"Unicode.Block.known_blocks/0","doc":"Returns a list of known Unicode\nblock names.\n\nThis function does not return the\nnames of any block aliases.","ref":"Unicode.Block.html#known_blocks/0"},{"type":"module","title":"Unicode.CanonicalCombiningClass","doc":"Functions to introspect Unicode\ncanonical combining classes for binaries\n(Strings) and codepoints.","ref":"Unicode.CanonicalCombiningClass.html"},{"type":"function","title":"Unicode.CanonicalCombiningClass.aliases/0","doc":"Returns a map of aliases for\nUnicode canonical combining classes..\n\nAn alias is an alternative name\nfor referring to a class. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.CanonicalCombiningClass.html#aliases/0"},{"type":"function","title":"Unicode.CanonicalCombiningClass.combining_class/1","doc":"Returns the canonical combining class\n name(s) for the given binary or codepoint.\n\nIn the case of a codepoint, a single\nclass name is returned.\n\nFor a binary a list of distinct class\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.CanonicalCombiningClass.html#combining_class/1"},{"type":"function","title":"Unicode.CanonicalCombiningClass.combining_classes/0","doc":"Returns the map of Unicode\ncanonical combining classes..\n\nThe class name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.CanonicalCombiningClass.html#combining_classes/0"},{"type":"function","title":"Unicode.CanonicalCombiningClass.count/1","doc":"Returns the count of the number of characters\nfor a given canonical combining class.","ref":"Unicode.CanonicalCombiningClass.html#count/1"},{"type":"function","title":"Example - Unicode.CanonicalCombiningClass.count/1","doc":"iex> Unicode.CanonicalCombiningClass.count(230)\n    517","ref":"Unicode.CanonicalCombiningClass.html#count/1-example"},{"type":"function","title":"Unicode.CanonicalCombiningClass.fetch/1","doc":"Returns the Unicode ranges for\na given canonical combining class\n as a list of ranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.CanonicalCombiningClass.html#fetch/1"},{"type":"function","title":"Unicode.CanonicalCombiningClass.get/1","doc":"Returns the Unicode ranges for\na given canonical combining class\n as a list of ranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.CanonicalCombiningClass.html#get/1"},{"type":"function","title":"Unicode.CanonicalCombiningClass.known_combining_classes/0","doc":"Returns a list of known Unicode\ncanonical combining class names.\n\nThis function does not return the\nnames of any class aliases.","ref":"Unicode.CanonicalCombiningClass.html#known_combining_classes/0"},{"type":"module","title":"Unicode.Category.QuoteMarks","doc":"Functions to return codepoints that form quotation marks. These\nmarks are taken from the [Wikipedia definition](https://en.wikipedia.org/wiki/Quotation_mark)\nwhich is more expansive than the Unicode categories [Pi](https://www.compart.com/en/unicode/category/Pi)\nand [Pf](https://www.compart.com/en/unicode/category/Pf).\n\nThe full list of codepoints considered to be quote marks is tabled here.","ref":"Unicode.Category.QuoteMarks.html"},{"type":"module","title":"Unicode code point table - Unicode.Category.QuoteMarks","doc":"These are codepoints noted in the Unicode character data base with the flag\n`quotation mark = yes`. These are equivalent to the unicode sets `Pi` and `Pf`.\n\n| Glyph | Code | Unicode name | HTML | Comments |\n| ----- | ---- | ------------ | ---- | -------- |\n| \" | U+0022 | Quotation mark | &amp;quot; | Typewriter (\"programmer's\") quote, ambidextrous. Also known as \"double quote\".\n| ' | U+0027 | Apostrophe | &amp;#39; | Typewriter (\"programmer's\") straight single quote, ambidextrous\n| « | U+00AB | Left-pointing double angle quotation mark | &amp;laquo; | Double angle quote\n| » | U+00BB | Right-pointing double angle quotation mark | &amp;raquo; | Double angle quote, right\n| ‘ | U+2018 | Left single quotation mark | &amp;lsquo; | Single curved quote, left. Also known as ''inverted [[comma]]'' or ''turned comma''\n| ’ | U+2019 | Right single quotation mark | &amp;rsquo; | Single curved quote, right\n| ‚ | U+201A | Single low-9 quotation mark | &amp;sbquo; | Low single curved quote, left\n| ‛ | U+201B | Single high-reversed-9 quotation mark | &amp;#8219; | also called ''single reversed comma'', ''quotation mark''\n| “ | U+201C | Left double quotation mark | &amp;ldquo; | Double curved quote, left\n| ” | U+201D | Right double quotation mark | &amp;rdquo; | Double curved quote, right\n| „ | U+201E | Double low-9 quotation mark | &amp;bdquo; | Low double curved quote, left\n| ‟ | U+201F | Double high-reversed-9 quotation mark | &amp;#8223; | also called ''double reversed comma'', ''quotation mark''\n| ‹ | U+2039 | Single left-pointing angle quotation mark | &amp;lsaquo; | Single angle quote, left\n| › | U+203A | Single right-pointing angle quotation mark | &amp;rsaquo; | Single angle quote, right\n| ⹂ | U+2E42 | Double low-reversed-9 quotation mark | &amp;#11842; | also called ''double low reversed comma'', ''quotation mark''","ref":"Unicode.Category.QuoteMarks.html#module-unicode-code-point-table"},{"type":"module","title":"Quotation marks in dingbats - Unicode.Category.QuoteMarks","doc":"| Glyph | Code | Unicode name | HTML | Comments |\n| ----- | ---- | ------------ | ---- | -------- |\n| ❛  | U+275B  | Heavy single turned comma quotation mark ornament | &amp;#10075; |  Quotation Mark=No \n| ❜  | U+275C  | Heavy single comma quotation mark ornament | &amp;#10076; |  Quotation Mark=No \n| ❝  | U+275D  | Heavy double turned comma quotation mark ornament | &amp;#10077; |  Quotation Mark=No \n| ❞  | U+275E  | Heavy double comma quotation mark ornament | &amp;#10078; |  Quotation Mark=No \n| 🙶 | U+1F676 | SANS-SERIF HEAVY DOUBLE TURNED COMMA QUOTATION MARK ORNAMENT | &amp;#128630; |  Quotation Mark=No \n| 🙷 | U+1F677 | SANS-SERIF HEAVY DOUBLE COMMA QUOTATION MARK ORNAMENT | &amp;#128631; |  Quotation Mark=No \n| 🙸 | U+1F678 | SANS-SERIF HEAVY LOW DOUBLE COMMA QUOTATION MARK ORNAMENT | &amp;#128632; |  Quotation Mark=No","ref":"Unicode.Category.QuoteMarks.html#module-quotation-marks-in-dingbats"},{"type":"module","title":"Quotation marks in Braille Patterns - Unicode.Category.QuoteMarks","doc":"| Glyph | Code | Unicode name | HTML | Comments |\n| ----- | ---- | ------------ | ---- | -------- |\n| ⠦ | U+2826 | Braille pattern dots-236 | &amp;#10292; | Braille double closing quotation mark;  Quotation Mark=No \n| ⠴ | U+2834 | Braille pattern dots-356 | &amp;#10278; | Braille double opening quotation mark;  Quotation Mark=No","ref":"Unicode.Category.QuoteMarks.html#module-quotation-marks-in-braille-patterns"},{"type":"module","title":"Quotation marks in Chinese, Japanese, and Korean - Unicode.Category.QuoteMarks","doc":"| Glyph | Code | Unicode name | HTML | Comments |\n| ----- | ---- | ------------ | ---- | -------- |\n| 「 | U+300C | Left corner bracket | &amp;#12300; | CJK\n| 」 | U+300D | Right corner bracket | &amp;#12301; | CJK\n| 『 | U+300E | Left white corner bracket | &amp;#12302; | CJK\n| 』 | U+300F | Right white corner bracket | &amp;#12303; | CJK\n| 〝 | U+301D | REVERSED DOUBLE PRIME QUOTATION MARK | &amp;#12317; | CJK\n| 〞 | U+301E | DOUBLE PRIME QUOTATION MARK | &amp;#12318; | CJK\n| 〟 | U+301F | LOW DOUBLE PRIME QUOTATION MARK | &amp;#12319; | CJK","ref":"Unicode.Category.QuoteMarks.html#module-quotation-marks-in-chinese-japanese-and-korean"},{"type":"module","title":"Alternate encodings - Unicode.Category.QuoteMarks","doc":"| Glyph | Code | Unicode name | HTML | Comments |\n| ----- | ---- | ------------ | ---- | -------- |\n| ﹁ | U+FE41 | PRESENTATION FORM FOR VERTICAL LEFT CORNER BRACKET | &amp;#65089; | CJK Compatibility, preferred use: U+300C\n| ﹂ | U+FE42 | PRESENTATION FORM FOR VERTICAL RIGHT CORNER BRACKET | &amp;#65090; | CJK Compatibility, preferred use: U+300D\n| ﹃ | U+FE43 | PRESENTATION FORM FOR VERTICAL LEFT WHITE CORNER BRACKET | &amp;#65091; | CJK Compatibility, preferred use: U+300E\n| ﹄ | U+FE44 | PRESENTATION FORM FOR VERTICAL RIGHT WHITE CORNER BRACKET | &amp;#65092; | CJK Compatibility, preferred use: U+300F\n| ＂ | U+FF02 | FULLWIDTH QUOTATION MARK | &amp;#65282; | Halfwidth and Fullwidth Forms, corresponds with U+0022\n| ＇ | U+FF07 | FULLWIDTH apostrophe | &amp;#65287; | Halfwidth and Fullwidth Forms, corresponds with U+0027\n| ｢ | U+FF62 | HALFWIDTH LEFT CORNER BRACKET | &amp;#65378; | Halfwidth and Fullwidth Forms, corresponds with U+300C\n| ｣ | U+FF63 | HALFWIDTH right CORNER BRACKET | &amp;#65379; | Halfwidth and Fullwidth Forms, corresponds with U+300D","ref":"Unicode.Category.QuoteMarks.html#module-alternate-encodings"},{"type":"function","title":"Unicode.Category.QuoteMarks.all_quote_marks/0","doc":"Return a list of codepoints representing all\nquote marks.","ref":"Unicode.Category.QuoteMarks.html#all_quote_marks/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_ambidextrous/0","doc":"Return a list of codepoints representing quote marks\ntypically used on the left or right (for LTR languages)","ref":"Unicode.Category.QuoteMarks.html#quote_marks_ambidextrous/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_braille/0","doc":"Return a list of codepoints representing quote marks\ntypically used in Braille","ref":"Unicode.Category.QuoteMarks.html#quote_marks_braille/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_double/0","doc":"Return a list of codepoints representing quote marks\nunderstood to be double marks","ref":"Unicode.Category.QuoteMarks.html#quote_marks_double/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_left/0","doc":"Return a list of codepoints representing quote marks\ntypically used on the left (for LTR languages)","ref":"Unicode.Category.QuoteMarks.html#quote_marks_left/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_right/0","doc":"Return a list of codepoints representing quote marks\ntypically used on the right (for LTR languages)","ref":"Unicode.Category.QuoteMarks.html#quote_marks_right/0"},{"type":"function","title":"Unicode.Category.QuoteMarks.quote_marks_single/0","doc":"Return a list of codepoints representing quote marks\nunderstood to be single marks","ref":"Unicode.Category.QuoteMarks.html#quote_marks_single/0"},{"type":"module","title":"Unicode.EastAsianWidth","doc":"Functions to introspect Unicode\neast asian width categories for binaries\n(Strings) and codepoints.","ref":"Unicode.EastAsianWidth.html"},{"type":"function","title":"Unicode.EastAsianWidth.aliases/0","doc":"Returns a map of aliases for\nUnicode east asian width categorys.\n\nAn alias is an alternative name\nfor referring to a east asian width category. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.EastAsianWidth.html#aliases/0"},{"type":"function","title":"Unicode.EastAsianWidth.count/1","doc":"Returns the count of the number of characters\nfor a given east asian width category.","ref":"Unicode.EastAsianWidth.html#count/1"},{"type":"function","title":"Example - Unicode.EastAsianWidth.count/1","doc":"iex> Unicode.IndicSyllabicCategory.count(:bindu)\n    91","ref":"Unicode.EastAsianWidth.html#count/1-example"},{"type":"function","title":"Unicode.EastAsianWidth.east_asian_width_categories/0","doc":"Returns the map of Unicode\neast asian width categorys.\n\nThe east asian width category name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.EastAsianWidth.html#east_asian_width_categories/0"},{"type":"function","title":"Unicode.EastAsianWidth.east_asian_width_category/1","doc":"Returns the east asian width category name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\neast asian width category name is returned.\n\nFor a binary a list of distinct east asian width category\nnames represented by the lines in\nthe binary is returned.","ref":"Unicode.EastAsianWidth.html#east_asian_width_category/1"},{"type":"function","title":"Unicode.EastAsianWidth.fetch/1","doc":"Returns the Unicode ranges for\na given east asian width category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.EastAsianWidth.html#fetch/1"},{"type":"function","title":"Unicode.EastAsianWidth.get/1","doc":"Returns the Unicode ranges for\na given east asian width category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.EastAsianWidth.html#get/1"},{"type":"function","title":"Unicode.EastAsianWidth.known_east_asian_width_categories/0","doc":"Returns a list of known Unicode\neast asian width category names.\n\nThis function does not return the\nnames of any east asian width category aliases.","ref":"Unicode.EastAsianWidth.html#known_east_asian_width_categories/0"},{"type":"module","title":"Unicode.GeneralCategory","doc":"Functions to introspect Unicode\ngeneral categories for binaries\n(Strings) and codepoints.","ref":"Unicode.GeneralCategory.html"},{"type":"function","title":"Unicode.GeneralCategory.aliases/0","doc":"Returns a map of aliases for\nUnicode categories.\n\nAn alias is an alternative name\nfor referring to a category. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.GeneralCategory.html#aliases/0"},{"type":"function","title":"Unicode.GeneralCategory.categories/0","doc":"Returns the map of Unicode\ncharacter categories.\n\nThe category name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.GeneralCategory.html#categories/0"},{"type":"function","title":"Unicode.GeneralCategory.category/1","doc":"Returns the category name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\ncategory name is returned.\n\nFor a binary a list of distinct category\nnames represented by the graphemes in\nthe binary is returned.\n\nOnly concrete general categories are considered,\nderived categories (:all, :ascii, :assigned etc)\nare not considered.","ref":"Unicode.GeneralCategory.html#category/1"},{"type":"function","title":"Unicode.GeneralCategory.count/1","doc":"Return the count of characters in a given\ncategory.","ref":"Unicode.GeneralCategory.html#count/1"},{"type":"function","title":"Example - Unicode.GeneralCategory.count/1","doc":"iex> Unicode.GeneralCategory.count(:Ll)\n    2258\n\n    iex> Unicode.GeneralCategory.count(:Nd)\n    760","ref":"Unicode.GeneralCategory.html#count/1-example"},{"type":"function","title":"Unicode.GeneralCategory.fetch/1","doc":"Returns the Unicode ranges for\na given category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.GeneralCategory.html#fetch/1"},{"type":"function","title":"Unicode.GeneralCategory.get/1","doc":"Returns the Unicode ranges for\na given category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.GeneralCategory.html#get/1"},{"type":"function","title":"Unicode.GeneralCategory.known_categories/0","doc":"Returns a list of known Unicode\ncategory names.\n\nThis function does not return the\nnames of any category aliases.","ref":"Unicode.GeneralCategory.html#known_categories/0"},{"type":"module","title":"Unicode.GeneralCategory.Derived","doc":"For certain operations and transformations\n(especially in [Unicode Sets](http://unicode.org/reports/tr35/#Unicode_Sets))\nthere is an expectation that certain derived\ngeneral categories exist even though they are not\ndefined in the unicode character database.\n\nThese categories are:\n\n* `:any` which is the full unicode character\n  range `0x0..0x10ffff`\n\n* `:assigned` which is the set of codepoints\n  that are assigned and is therefore\n  equivalent to `[:any]-[:Cn]`. In fact that is\n  exactly how it is calculated using [unicode_set](https://hex.pm/packages/unicode_set)\n  and the results are copied here so\n  that there is no mutual dependency.\n\n* `:ascii` which is the range for the US ASCII\n  character set of `0x0..0x7f`\n\nIn addition there are derived categories\nnot part of the Unicode specification that\nsupport additional use cases. These include:\n\n* Categories related to\n  recognising quotation marks. See the\n  module `Unicode.Category.QuoteMarks`.\n\n* `:printable` which implements the same\n  semantics as `String.printable?/1`. This is\n  a very broad definition of printable characters.\n\n* `:graph` which includes characters from the\n  `[^\\p{space}\\p{gc=Control}\\p{gc=Surrogate}\\p{gc=Unassigned}]`\n  set defined by [Unicode Regular Expressions](http://unicode.org/reports/tr18/).","ref":"Unicode.GeneralCategory.Derived.html"},{"type":"function","title":"Unicode.GeneralCategory.Derived.aliases/0","doc":"Returns a map of the aliases\nfor the derived General Categories","ref":"Unicode.GeneralCategory.Derived.html#aliases/0"},{"type":"function","title":"Unicode.GeneralCategory.Derived.categories/0","doc":"Returns a map of the derived\nGeneral Categories","ref":"Unicode.GeneralCategory.Derived.html#categories/0"},{"type":"module","title":"Unicode.GraphemeClusterBreak","doc":"Functions to introspect Unicode\ngrapheme cluster breaks for binaries\n(Strings) and codepoints.","ref":"Unicode.GraphemeClusterBreak.html"},{"type":"function","title":"Unicode.GraphemeClusterBreak.aliases/0","doc":"Returns a map of aliases for\nUnicode grapheme cluster breaks.\n\nAn alias is an alternative name\nfor referring to a grapheme cluster break. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.GraphemeClusterBreak.html#aliases/0"},{"type":"function","title":"Unicode.GraphemeClusterBreak.count/1","doc":"Returns the count of the number of characters\nfor a given grapheme cluster break.","ref":"Unicode.GraphemeClusterBreak.html#count/1"},{"type":"function","title":"Example - Unicode.GraphemeClusterBreak.count/1","doc":"iex> Unicode.GraphemeClusterBreak.count(:prepend)\n    28","ref":"Unicode.GraphemeClusterBreak.html#count/1-example"},{"type":"function","title":"Unicode.GraphemeClusterBreak.fetch/1","doc":"Returns the Unicode ranges for\na given grapheme cluster break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.GraphemeClusterBreak.html#fetch/1"},{"type":"function","title":"Unicode.GraphemeClusterBreak.get/1","doc":"Returns the Unicode ranges for\na given grapheme cluster break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.GraphemeClusterBreak.html#get/1"},{"type":"function","title":"Unicode.GraphemeClusterBreak.grapheme_break/1","doc":"Returns the grapheme cluster break name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\ngrapheme cluster break name is returned.\n\nFor a binary a list of distinct grapheme cluster break\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.GraphemeClusterBreak.html#grapheme_break/1"},{"type":"function","title":"Unicode.GraphemeClusterBreak.grapheme_breaks/0","doc":"Returns the map of Unicode\ngrapheme cluster breaks.\n\nThe grapheme cluster break name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.GraphemeClusterBreak.html#grapheme_breaks/0"},{"type":"function","title":"Unicode.GraphemeClusterBreak.known_grapheme_breaks/0","doc":"Returns a list of known Unicode\ngrapheme cluster break names.\n\nThis function does not return the\nnames of any grapheme cluster break aliases.","ref":"Unicode.GraphemeClusterBreak.html#known_grapheme_breaks/0"},{"type":"module","title":"Unicode.IndicConjunctBreak","doc":"Property manager for the Unicode Indic Conjunction Break\nproperty.","ref":"Unicode.IndicConjunctBreak.html"},{"type":"function","title":"Unicode.IndicConjunctBreak.aliases/0","doc":"Returns a map of aliases for\nUnicode indic_conjunct_breaks.\n\nAn alias is an alternative name\nfor referring to a indic_conjunct_break. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.IndicConjunctBreak.html#aliases/0"},{"type":"function","title":"Unicode.IndicConjunctBreak.count/1","doc":"Returns the count of the number of characters\nfor a given indic_conjunct_break.","ref":"Unicode.IndicConjunctBreak.html#count/1"},{"type":"function","title":"Example - Unicode.IndicConjunctBreak.count/1","doc":"iex> Unicode.Script.count(\"mongolian\")\n    168","ref":"Unicode.IndicConjunctBreak.html#count/1-example"},{"type":"function","title":"Unicode.IndicConjunctBreak.fetch/1","doc":"Returns the Unicode ranges for\na given indic_conjunct_break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.IndicConjunctBreak.html#fetch/1"},{"type":"function","title":"Unicode.IndicConjunctBreak.get/1","doc":"Returns the Unicode ranges for\na given indic_conjunct_break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.IndicConjunctBreak.html#get/1"},{"type":"function","title":"Unicode.IndicConjunctBreak.indic_conjunct_break/0","doc":"Returns the map of Unicode\nIndic Conjunction Breaks..","ref":"Unicode.IndicConjunctBreak.html#indic_conjunct_break/0"},{"type":"function","title":"Unicode.IndicConjunctBreak.indic_conjunct_break/1","doc":"Returns the indic_conjunct_break name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nindic_conjunct_break name is returned.\n\nFor a binary a list of distinct indic_conjunct_break\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.IndicConjunctBreak.html#indic_conjunct_break/1"},{"type":"function","title":"Unicode.IndicConjunctBreak.known_indic_conjunct_breaks/0","doc":"Returns a list of known Unicode\nindic_conjunct_break names.\n\nThis function does not return the\nnames of any indic_conjunct_break aliases.","ref":"Unicode.IndicConjunctBreak.html#known_indic_conjunct_breaks/0"},{"type":"module","title":"Unicode.IndicSyllabicCategory","doc":"Functions to introspect Unicode\nindic syllabic categories for binaries\n(Strings) and codepoints.","ref":"Unicode.IndicSyllabicCategory.html"},{"type":"function","title":"Unicode.IndicSyllabicCategory.aliases/0","doc":"Returns a map of aliases for\nUnicode indic syllabic categorys.\n\nAn alias is an alternative name\nfor referring to a indic syllabic category. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.IndicSyllabicCategory.html#aliases/0"},{"type":"function","title":"Unicode.IndicSyllabicCategory.count/1","doc":"Returns the count of the number of characters\nfor a given indic syllabic category.","ref":"Unicode.IndicSyllabicCategory.html#count/1"},{"type":"function","title":"Example - Unicode.IndicSyllabicCategory.count/1","doc":"iex> Unicode.IndicSyllabicCategory.count(:bindu)\n    99","ref":"Unicode.IndicSyllabicCategory.html#count/1-example"},{"type":"function","title":"Unicode.IndicSyllabicCategory.fetch/1","doc":"Returns the Unicode ranges for\na given indic syllabic category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.IndicSyllabicCategory.html#fetch/1"},{"type":"function","title":"Unicode.IndicSyllabicCategory.get/1","doc":"Returns the Unicode ranges for\na given indic syllabic category as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.IndicSyllabicCategory.html#get/1"},{"type":"function","title":"Unicode.IndicSyllabicCategory.indic_syllabic_categories/0","doc":"Returns the map of Unicode\nindic syllabic categorys.\n\nThe indic syllabic category name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.IndicSyllabicCategory.html#indic_syllabic_categories/0"},{"type":"function","title":"Unicode.IndicSyllabicCategory.indic_syllabic_category/1","doc":"Returns the indic syllabic category name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nindic syllabic category name is returned.\n\nFor a binary a list of distinct indic syllabic category\nnames represented by the lines in\nthe binary is returned.","ref":"Unicode.IndicSyllabicCategory.html#indic_syllabic_category/1"},{"type":"function","title":"Unicode.IndicSyllabicCategory.known_indic_syllabic_categories/0","doc":"Returns a list of known Unicode\nindic syllabic category names.\n\nThis function does not return the\nnames of any indic syllabic category aliases.","ref":"Unicode.IndicSyllabicCategory.html#known_indic_syllabic_categories/0"},{"type":"module","title":"Unicode.LineBreak","doc":"Functions to introspect Unicode\nline breaks for binaries\n(Strings) and codepoints.","ref":"Unicode.LineBreak.html"},{"type":"function","title":"Unicode.LineBreak.aliases/0","doc":"Returns a map of aliases for\nUnicode line breaks.\n\nAn alias is an alternative name\nfor referring to a line break. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.LineBreak.html#aliases/0"},{"type":"function","title":"Unicode.LineBreak.count/1","doc":"Returns the count of the number of characters\nfor a given line_break.","ref":"Unicode.LineBreak.html#count/1"},{"type":"function","title":"Example - Unicode.LineBreak.count/1","doc":"iex> Unicode.LineBreak.count(:al)\n    26679","ref":"Unicode.LineBreak.html#count/1-example"},{"type":"function","title":"Unicode.LineBreak.fetch/1","doc":"Returns the Unicode ranges for\na given line break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.LineBreak.html#fetch/1"},{"type":"function","title":"Unicode.LineBreak.get/1","doc":"Returns the Unicode ranges for\na given line break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.LineBreak.html#get/1"},{"type":"function","title":"Unicode.LineBreak.known_line_breaks/0","doc":"Returns a list of known Unicode\nline break names.\n\nThis function does not return the\nnames of any line break aliases.","ref":"Unicode.LineBreak.html#known_line_breaks/0"},{"type":"function","title":"Unicode.LineBreak.line_break/1","doc":"Returns the line break name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nline_break name is returned.\n\nFor a binary a list of distinct line break\nnames represented by the lines in\nthe binary is returned.","ref":"Unicode.LineBreak.html#line_break/1"},{"type":"function","title":"Unicode.LineBreak.line_breaks/0","doc":"Returns the map of Unicode\nline breaks.\n\nThe line break name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.LineBreak.html#line_breaks/0"},{"type":"module","title":"Unicode.Property","doc":"Functions to introspect Unicode properties for binaries\n(Strings) and codepoints.\n\nThe functions in this module only represent boolean\nproperties. That is, properties that are either true\nor false - or in several cases represented as \"has property\"\nor \"does not have property\".","ref":"Unicode.Property.html"},{"type":"function","title":"Unicode.Property.aliases/0","doc":"Returns a map of aliases for\nUnicode blocks.\n\nAn alias is an alternative name\nfor referring to a block. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.Property.html#aliases/0"},{"type":"function","title":"Unicode.Property.alphabetic/1","doc":"Returns `:alphabetic` or `nil` indicating\nif the codepoint or string has the property\n`:alphabetic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:alphabetic`\nproperty in order for the result to `:alphabetic`.","ref":"Unicode.Property.html#alphabetic/1"},{"type":"function","title":"Unicode.Property.alphabetic?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:alphabetic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:alphabetic`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#alphabetic?/1"},{"type":"function","title":"Unicode.Property.alphanumeric/1","doc":"Returns `:alphanumeric` or `nil` based upon\nwhether the given codepoint or binary\nis all alphanumeric characters.\n\nThis is useful when the desired result is\n`truthy` or `falsy`","ref":"Unicode.Property.html#alphanumeric/1"},{"type":"function","title":"Example - Unicode.Property.alphanumeric/1","doc":"iex> Unicode.Property.alphanumeric \"123abc\"\n    :alphanumeric\n    iex> Unicode.Property.alphanumeric \"???\"\n    nil","ref":"Unicode.Property.html#alphanumeric/1-example"},{"type":"function","title":"Unicode.Property.alphanumeric?/1","doc":"Returns a boolean based upon\nwhether the given codepoint or binary\nis all alphanumeric characters.","ref":"Unicode.Property.html#alphanumeric?/1"},{"type":"function","title":"Example - Unicode.Property.alphanumeric?/1","doc":"iex> Unicode.Property.alphanumeric? \"123abc\"\n    true\n    iex> Unicode.Property.alphanumeric? \"⅔\"\n    false","ref":"Unicode.Property.html#alphanumeric?/1-example"},{"type":"function","title":"Unicode.Property.ascii_hex_digit/1","doc":"Returns `:ascii_hex_digit` or `nil` indicating\nif the codepoint or string has the property\n`:ascii_hex_digit`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ascii_hex_digit`\nproperty in order for the result to `:ascii_hex_digit`.","ref":"Unicode.Property.html#ascii_hex_digit/1"},{"type":"function","title":"Unicode.Property.ascii_hex_digit?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:ascii_hex_digit`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ascii_hex_digit`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#ascii_hex_digit?/1"},{"type":"function","title":"Unicode.Property.bidi_control/1","doc":"Returns `:bidi_control` or `nil` indicating\nif the codepoint or string has the property\n`:bidi_control`.\n\nFor string parameters, all codepoints in\nthe string must have the `:bidi_control`\nproperty in order for the result to `:bidi_control`.","ref":"Unicode.Property.html#bidi_control/1"},{"type":"function","title":"Unicode.Property.bidi_control?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:bidi_control`.\n\nFor string parameters, all codepoints in\nthe string must have the `:bidi_control`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#bidi_control?/1"},{"type":"function","title":"Unicode.Property.case_ignorable/1","doc":"Returns `:case_ignorable` or `nil` indicating\nif the codepoint or string has the property\n`:case_ignorable`.\n\nFor string parameters, all codepoints in\nthe string must have the `:case_ignorable`\nproperty in order for the result to `:case_ignorable`.","ref":"Unicode.Property.html#case_ignorable/1"},{"type":"function","title":"Unicode.Property.case_ignorable?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:case_ignorable`.\n\nFor string parameters, all codepoints in\nthe string must have the `:case_ignorable`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#case_ignorable?/1"},{"type":"function","title":"Unicode.Property.cased/1","doc":"Returns `:cased` or `nil` indicating\nif the codepoint or string has the property\n`:cased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:cased`\nproperty in order for the result to `:cased`.","ref":"Unicode.Property.html#cased/1"},{"type":"function","title":"Unicode.Property.cased?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:cased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:cased`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#cased?/1"},{"type":"function","title":"Unicode.Property.changes_when_casefolded/1","doc":"Returns `:changes_when_casefolded` or `nil` indicating\nif the codepoint or string has the property\n`:changes_when_casefolded`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_casefolded`\nproperty in order for the result to `:changes_when_casefolded`.","ref":"Unicode.Property.html#changes_when_casefolded/1"},{"type":"function","title":"Unicode.Property.changes_when_casefolded?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:changes_when_casefolded`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_casefolded`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#changes_when_casefolded?/1"},{"type":"function","title":"Unicode.Property.changes_when_casemapped/1","doc":"Returns `:changes_when_casemapped` or `nil` indicating\nif the codepoint or string has the property\n`:changes_when_casemapped`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_casemapped`\nproperty in order for the result to `:changes_when_casemapped`.","ref":"Unicode.Property.html#changes_when_casemapped/1"},{"type":"function","title":"Unicode.Property.changes_when_casemapped?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:changes_when_casemapped`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_casemapped`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#changes_when_casemapped?/1"},{"type":"function","title":"Unicode.Property.changes_when_lowercased/1","doc":"Returns `:changes_when_lowercased` or `nil` indicating\nif the codepoint or string has the property\n`:changes_when_lowercased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_lowercased`\nproperty in order for the result to `:changes_when_lowercased`.","ref":"Unicode.Property.html#changes_when_lowercased/1"},{"type":"function","title":"Unicode.Property.changes_when_lowercased?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:changes_when_lowercased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_lowercased`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#changes_when_lowercased?/1"},{"type":"function","title":"Unicode.Property.changes_when_titlecased/1","doc":"Returns `:changes_when_titlecased` or `nil` indicating\nif the codepoint or string has the property\n`:changes_when_titlecased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_titlecased`\nproperty in order for the result to `:changes_when_titlecased`.","ref":"Unicode.Property.html#changes_when_titlecased/1"},{"type":"function","title":"Unicode.Property.changes_when_titlecased?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:changes_when_titlecased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_titlecased`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#changes_when_titlecased?/1"},{"type":"function","title":"Unicode.Property.changes_when_uppercased/1","doc":"Returns `:changes_when_uppercased` or `nil` indicating\nif the codepoint or string has the property\n`:changes_when_uppercased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_uppercased`\nproperty in order for the result to `:changes_when_uppercased`.","ref":"Unicode.Property.html#changes_when_uppercased/1"},{"type":"function","title":"Unicode.Property.changes_when_uppercased?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:changes_when_uppercased`.\n\nFor string parameters, all codepoints in\nthe string must have the `:changes_when_uppercased`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#changes_when_uppercased?/1"},{"type":"function","title":"Unicode.Property.count/1","doc":"Returns the count of the number of characters\nfor a given property.","ref":"Unicode.Property.html#count/1"},{"type":"function","title":"Example - Unicode.Property.count/1","doc":"iex> Unicode.Property.count(:lowercase)\n    2569","ref":"Unicode.Property.html#count/1-example"},{"type":"function","title":"Unicode.Property.dash/1","doc":"Returns `:dash` or `nil` indicating\nif the codepoint or string has the property\n`:dash`.\n\nFor string parameters, all codepoints in\nthe string must have the `:dash`\nproperty in order for the result to `:dash`.","ref":"Unicode.Property.html#dash/1"},{"type":"function","title":"Unicode.Property.dash?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:dash`.\n\nFor string parameters, all codepoints in\nthe string must have the `:dash`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#dash?/1"},{"type":"function","title":"Unicode.Property.default_ignorable_code_point/1","doc":"Returns `:default_ignorable_code_point` or `nil` indicating\nif the codepoint or string has the property\n`:default_ignorable_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:default_ignorable_code_point`\nproperty in order for the result to `:default_ignorable_code_point`.","ref":"Unicode.Property.html#default_ignorable_code_point/1"},{"type":"function","title":"Unicode.Property.default_ignorable_code_point?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:default_ignorable_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:default_ignorable_code_point`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#default_ignorable_code_point?/1"},{"type":"function","title":"Unicode.Property.deprecated/1","doc":"Returns `:deprecated` or `nil` indicating\nif the codepoint or string has the property\n`:deprecated`.\n\nFor string parameters, all codepoints in\nthe string must have the `:deprecated`\nproperty in order for the result to `:deprecated`.","ref":"Unicode.Property.html#deprecated/1"},{"type":"function","title":"Unicode.Property.deprecated?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:deprecated`.\n\nFor string parameters, all codepoints in\nthe string must have the `:deprecated`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#deprecated?/1"},{"type":"function","title":"Unicode.Property.diacritic/1","doc":"Returns `:diacritic` or `nil` indicating\nif the codepoint or string has the property\n`:diacritic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:diacritic`\nproperty in order for the result to `:diacritic`.","ref":"Unicode.Property.html#diacritic/1"},{"type":"function","title":"Unicode.Property.diacritic?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:diacritic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:diacritic`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#diacritic?/1"},{"type":"function","title":"Unicode.Property.emoji/1","doc":"Returns `:emoji` or `nil` indicating\nif the codepoint or string has the property\n`:emoji`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji`\nproperty in order for the result to `:emoji`.","ref":"Unicode.Property.html#emoji/1"},{"type":"function","title":"Unicode.Property.emoji?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:emoji`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#emoji?/1"},{"type":"function","title":"Unicode.Property.emoji_component/1","doc":"Returns `:emoji_component` or `nil` indicating\nif the codepoint or string has the property\n`:emoji_component`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_component`\nproperty in order for the result to `:emoji_component`.","ref":"Unicode.Property.html#emoji_component/1"},{"type":"function","title":"Unicode.Property.emoji_component?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:emoji_component`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_component`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#emoji_component?/1"},{"type":"function","title":"Unicode.Property.emoji_modifier/1","doc":"Returns `:emoji_modifier` or `nil` indicating\nif the codepoint or string has the property\n`:emoji_modifier`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_modifier`\nproperty in order for the result to `:emoji_modifier`.","ref":"Unicode.Property.html#emoji_modifier/1"},{"type":"function","title":"Unicode.Property.emoji_modifier?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:emoji_modifier`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_modifier`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#emoji_modifier?/1"},{"type":"function","title":"Unicode.Property.emoji_modifier_base/1","doc":"Returns `:emoji_modifier_base` or `nil` indicating\nif the codepoint or string has the property\n`:emoji_modifier_base`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_modifier_base`\nproperty in order for the result to `:emoji_modifier_base`.","ref":"Unicode.Property.html#emoji_modifier_base/1"},{"type":"function","title":"Unicode.Property.emoji_modifier_base?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:emoji_modifier_base`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_modifier_base`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#emoji_modifier_base?/1"},{"type":"function","title":"Unicode.Property.emoji_presentation/1","doc":"Returns `:emoji_presentation` or `nil` indicating\nif the codepoint or string has the property\n`:emoji_presentation`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_presentation`\nproperty in order for the result to `:emoji_presentation`.","ref":"Unicode.Property.html#emoji_presentation/1"},{"type":"function","title":"Unicode.Property.emoji_presentation?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:emoji_presentation`.\n\nFor string parameters, all codepoints in\nthe string must have the `:emoji_presentation`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#emoji_presentation?/1"},{"type":"function","title":"Unicode.Property.extended_numeric/1","doc":"Returns `:extended_numeric` or `nil` based upon\nwhether the given codepoint or binary\nis all alphanumeric characters.\n\nExtended numberic includes fractions, superscripts,\nsubscripts and other characters in the category `No`.\n\nThis is useful when the desired result is\n`truthy` or `falsy`","ref":"Unicode.Property.html#extended_numeric/1"},{"type":"function","title":"Example - Unicode.Property.extended_numeric/1","doc":"iex> Unicode.Property.extended_numeric \"123\"\n    :extended_numeric\n    iex> Unicode.Property.extended_numeric \"⅔\"\n    :extended_numeric\n    iex> Unicode.Property.extended_numeric \"-123\"\n    nil","ref":"Unicode.Property.html#extended_numeric/1-example"},{"type":"function","title":"Unicode.Property.extended_numeric?/1","doc":"Returns a boolean based upon\nwhether the given codepoint or binary\nis all numberic characters.","ref":"Unicode.Property.html#extended_numeric?/1"},{"type":"function","title":"Example - Unicode.Property.extended_numeric?/1","doc":"iex> Unicode.Property.extended_numeric? \"123\"\n   true\n   iex> Unicode.Property.extended_numeric? \"⅔\"\n   true","ref":"Unicode.Property.html#extended_numeric?/1-example"},{"type":"function","title":"Unicode.Property.extended_pictographic/1","doc":"Returns `:extended_pictographic` or `nil` indicating\nif the codepoint or string has the property\n`:extended_pictographic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:extended_pictographic`\nproperty in order for the result to `:extended_pictographic`.","ref":"Unicode.Property.html#extended_pictographic/1"},{"type":"function","title":"Unicode.Property.extended_pictographic?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:extended_pictographic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:extended_pictographic`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#extended_pictographic?/1"},{"type":"function","title":"Unicode.Property.extender/1","doc":"Returns `:extender` or `nil` indicating\nif the codepoint or string has the property\n`:extender`.\n\nFor string parameters, all codepoints in\nthe string must have the `:extender`\nproperty in order for the result to `:extender`.","ref":"Unicode.Property.html#extender/1"},{"type":"function","title":"Unicode.Property.extender?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:extender`.\n\nFor string parameters, all codepoints in\nthe string must have the `:extender`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#extender?/1"},{"type":"function","title":"Unicode.Property.fetch/1","doc":"Returns the Unicode ranges for\na given block as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.Property.html#fetch/1"},{"type":"function","title":"Unicode.Property.get/1","doc":"Returns the Unicode ranges for\na given block as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.Property.html#get/1"},{"type":"function","title":"Unicode.Property.grapheme_base/1","doc":"Returns `:grapheme_base` or `nil` indicating\nif the codepoint or string has the property\n`:grapheme_base`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_base`\nproperty in order for the result to `:grapheme_base`.","ref":"Unicode.Property.html#grapheme_base/1"},{"type":"function","title":"Unicode.Property.grapheme_base?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:grapheme_base`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_base`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#grapheme_base?/1"},{"type":"function","title":"Unicode.Property.grapheme_extend/1","doc":"Returns `:grapheme_extend` or `nil` indicating\nif the codepoint or string has the property\n`:grapheme_extend`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_extend`\nproperty in order for the result to `:grapheme_extend`.","ref":"Unicode.Property.html#grapheme_extend/1"},{"type":"function","title":"Unicode.Property.grapheme_extend?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:grapheme_extend`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_extend`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#grapheme_extend?/1"},{"type":"function","title":"Unicode.Property.grapheme_link/1","doc":"Returns `:grapheme_link` or `nil` indicating\nif the codepoint or string has the property\n`:grapheme_link`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_link`\nproperty in order for the result to `:grapheme_link`.","ref":"Unicode.Property.html#grapheme_link/1"},{"type":"function","title":"Unicode.Property.grapheme_link?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:grapheme_link`.\n\nFor string parameters, all codepoints in\nthe string must have the `:grapheme_link`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#grapheme_link?/1"},{"type":"function","title":"Unicode.Property.hex_digit/1","doc":"Returns `:hex_digit` or `nil` indicating\nif the codepoint or string has the property\n`:hex_digit`.\n\nFor string parameters, all codepoints in\nthe string must have the `:hex_digit`\nproperty in order for the result to `:hex_digit`.","ref":"Unicode.Property.html#hex_digit/1"},{"type":"function","title":"Unicode.Property.hex_digit?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:hex_digit`.\n\nFor string parameters, all codepoints in\nthe string must have the `:hex_digit`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#hex_digit?/1"},{"type":"function","title":"Unicode.Property.hyphen/1","doc":"Returns `:hyphen` or `nil` indicating\nif the codepoint or string has the property\n`:hyphen`.\n\nFor string parameters, all codepoints in\nthe string must have the `:hyphen`\nproperty in order for the result to `:hyphen`.","ref":"Unicode.Property.html#hyphen/1"},{"type":"function","title":"Unicode.Property.hyphen?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:hyphen`.\n\nFor string parameters, all codepoints in\nthe string must have the `:hyphen`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#hyphen?/1"},{"type":"function","title":"Unicode.Property.id_compat_math_continue/1","doc":"Returns `:id_compat_math_continue` or `nil` indicating\nif the codepoint or string has the property\n`:id_compat_math_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_compat_math_continue`\nproperty in order for the result to `:id_compat_math_continue`.","ref":"Unicode.Property.html#id_compat_math_continue/1"},{"type":"function","title":"Unicode.Property.id_compat_math_continue?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:id_compat_math_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_compat_math_continue`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#id_compat_math_continue?/1"},{"type":"function","title":"Unicode.Property.id_compat_math_start/1","doc":"Returns `:id_compat_math_start` or `nil` indicating\nif the codepoint or string has the property\n`:id_compat_math_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_compat_math_start`\nproperty in order for the result to `:id_compat_math_start`.","ref":"Unicode.Property.html#id_compat_math_start/1"},{"type":"function","title":"Unicode.Property.id_compat_math_start?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:id_compat_math_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_compat_math_start`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#id_compat_math_start?/1"},{"type":"function","title":"Unicode.Property.id_continue/1","doc":"Returns `:id_continue` or `nil` indicating\nif the codepoint or string has the property\n`:id_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_continue`\nproperty in order for the result to `:id_continue`.","ref":"Unicode.Property.html#id_continue/1"},{"type":"function","title":"Unicode.Property.id_continue?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:id_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_continue`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#id_continue?/1"},{"type":"function","title":"Unicode.Property.id_start/1","doc":"Returns `:id_start` or `nil` indicating\nif the codepoint or string has the property\n`:id_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_start`\nproperty in order for the result to `:id_start`.","ref":"Unicode.Property.html#id_start/1"},{"type":"function","title":"Unicode.Property.id_start?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:id_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:id_start`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#id_start?/1"},{"type":"function","title":"Unicode.Property.ideographic/1","doc":"Returns `:ideographic` or `nil` indicating\nif the codepoint or string has the property\n`:ideographic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ideographic`\nproperty in order for the result to `:ideographic`.","ref":"Unicode.Property.html#ideographic/1"},{"type":"function","title":"Unicode.Property.ideographic?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:ideographic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ideographic`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#ideographic?/1"},{"type":"function","title":"Unicode.Property.ids_binary_operator/1","doc":"Returns `:ids_binary_operator` or `nil` indicating\nif the codepoint or string has the property\n`:ids_binary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_binary_operator`\nproperty in order for the result to `:ids_binary_operator`.","ref":"Unicode.Property.html#ids_binary_operator/1"},{"type":"function","title":"Unicode.Property.ids_binary_operator?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:ids_binary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_binary_operator`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#ids_binary_operator?/1"},{"type":"function","title":"Unicode.Property.ids_trinary_operator/1","doc":"Returns `:ids_trinary_operator` or `nil` indicating\nif the codepoint or string has the property\n`:ids_trinary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_trinary_operator`\nproperty in order for the result to `:ids_trinary_operator`.","ref":"Unicode.Property.html#ids_trinary_operator/1"},{"type":"function","title":"Unicode.Property.ids_trinary_operator?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:ids_trinary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_trinary_operator`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#ids_trinary_operator?/1"},{"type":"function","title":"Unicode.Property.ids_unary_operator/1","doc":"Returns `:ids_unary_operator` or `nil` indicating\nif the codepoint or string has the property\n`:ids_unary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_unary_operator`\nproperty in order for the result to `:ids_unary_operator`.","ref":"Unicode.Property.html#ids_unary_operator/1"},{"type":"function","title":"Unicode.Property.ids_unary_operator?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:ids_unary_operator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:ids_unary_operator`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#ids_unary_operator?/1"},{"type":"function","title":"Unicode.Property.incb/1","doc":"Returns `:incb` or `nil` indicating\nif the codepoint or string has the property\n`:incb`.\n\nFor string parameters, all codepoints in\nthe string must have the `:incb`\nproperty in order for the result to `:incb`.","ref":"Unicode.Property.html#incb/1"},{"type":"function","title":"Unicode.Property.incb?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:incb`.\n\nFor string parameters, all codepoints in\nthe string must have the `:incb`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#incb?/1"},{"type":"function","title":"Unicode.Property.join_control/1","doc":"Returns `:join_control` or `nil` indicating\nif the codepoint or string has the property\n`:join_control`.\n\nFor string parameters, all codepoints in\nthe string must have the `:join_control`\nproperty in order for the result to `:join_control`.","ref":"Unicode.Property.html#join_control/1"},{"type":"function","title":"Unicode.Property.join_control?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:join_control`.\n\nFor string parameters, all codepoints in\nthe string must have the `:join_control`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#join_control?/1"},{"type":"function","title":"Unicode.Property.known_properties/0","doc":"Returns a list of known Unicode\nproperty names.\n\nThis function does not return the\nnames of any property aliases.","ref":"Unicode.Property.html#known_properties/0"},{"type":"function","title":"Unicode.Property.logical_order_exception/1","doc":"Returns `:logical_order_exception` or `nil` indicating\nif the codepoint or string has the property\n`:logical_order_exception`.\n\nFor string parameters, all codepoints in\nthe string must have the `:logical_order_exception`\nproperty in order for the result to `:logical_order_exception`.","ref":"Unicode.Property.html#logical_order_exception/1"},{"type":"function","title":"Unicode.Property.logical_order_exception?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:logical_order_exception`.\n\nFor string parameters, all codepoints in\nthe string must have the `:logical_order_exception`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#logical_order_exception?/1"},{"type":"function","title":"Unicode.Property.lowercase/1","doc":"Returns `:lowercase` or `nil` indicating\nif the codepoint or string has the property\n`:lowercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:lowercase`\nproperty in order for the result to `:lowercase`.","ref":"Unicode.Property.html#lowercase/1"},{"type":"function","title":"Unicode.Property.lowercase?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:lowercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:lowercase`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#lowercase?/1"},{"type":"function","title":"Unicode.Property.math/1","doc":"Returns `:math` or `nil` indicating\nif the codepoint or string has the property\n`:math`.\n\nFor string parameters, all codepoints in\nthe string must have the `:math`\nproperty in order for the result to `:math`.","ref":"Unicode.Property.html#math/1"},{"type":"function","title":"Unicode.Property.math?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:math`.\n\nFor string parameters, all codepoints in\nthe string must have the `:math`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#math?/1"},{"type":"function","title":"Unicode.Property.modifier_combining_mark/1","doc":"Returns `:modifier_combining_mark` or `nil` indicating\nif the codepoint or string has the property\n`:modifier_combining_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:modifier_combining_mark`\nproperty in order for the result to `:modifier_combining_mark`.","ref":"Unicode.Property.html#modifier_combining_mark/1"},{"type":"function","title":"Unicode.Property.modifier_combining_mark?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:modifier_combining_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:modifier_combining_mark`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#modifier_combining_mark?/1"},{"type":"function","title":"Unicode.Property.noncharacter_code_point/1","doc":"Returns `:noncharacter_code_point` or `nil` indicating\nif the codepoint or string has the property\n`:noncharacter_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:noncharacter_code_point`\nproperty in order for the result to `:noncharacter_code_point`.","ref":"Unicode.Property.html#noncharacter_code_point/1"},{"type":"function","title":"Unicode.Property.noncharacter_code_point?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:noncharacter_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:noncharacter_code_point`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#noncharacter_code_point?/1"},{"type":"function","title":"Unicode.Property.numeric/1","doc":"Returns `:numeric` or `nil` based upon\nwhether the given codepoint or binary\nis all numeric characters.\n\nThis is useful when the desired result is\n`truthy` or `falsy`","ref":"Unicode.Property.html#numeric/1"},{"type":"function","title":"Example - Unicode.Property.numeric/1","doc":"iex> Unicode.Property.numeric \"123\"\n    :numeric\n    iex> Unicode.Property.numeric \"123a\"\n    nil","ref":"Unicode.Property.html#numeric/1-example"},{"type":"function","title":"Unicode.Property.numeric?/1","doc":"Returns a boolean based upon\nwhether the given codepoint or binary\nis all numeric characters.","ref":"Unicode.Property.html#numeric?/1"},{"type":"function","title":"Example - Unicode.Property.numeric?/1","doc":"iex> Unicode.Property.numeric? \"123\"\n    true\n    iex> Unicode.Property.numeric? \"123a\"\n    false","ref":"Unicode.Property.html#numeric?/1-example"},{"type":"function","title":"Unicode.Property.other_alphabetic/1","doc":"Returns `:other_alphabetic` or `nil` indicating\nif the codepoint or string has the property\n`:other_alphabetic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_alphabetic`\nproperty in order for the result to `:other_alphabetic`.","ref":"Unicode.Property.html#other_alphabetic/1"},{"type":"function","title":"Unicode.Property.other_alphabetic?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_alphabetic`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_alphabetic`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_alphabetic?/1"},{"type":"function","title":"Unicode.Property.other_default_ignorable_code_point/1","doc":"Returns `:other_default_ignorable_code_point` or `nil` indicating\nif the codepoint or string has the property\n`:other_default_ignorable_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_default_ignorable_code_point`\nproperty in order for the result to `:other_default_ignorable_code_point`.","ref":"Unicode.Property.html#other_default_ignorable_code_point/1"},{"type":"function","title":"Unicode.Property.other_default_ignorable_code_point?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_default_ignorable_code_point`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_default_ignorable_code_point`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_default_ignorable_code_point?/1"},{"type":"function","title":"Unicode.Property.other_grapheme_extend/1","doc":"Returns `:other_grapheme_extend` or `nil` indicating\nif the codepoint or string has the property\n`:other_grapheme_extend`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_grapheme_extend`\nproperty in order for the result to `:other_grapheme_extend`.","ref":"Unicode.Property.html#other_grapheme_extend/1"},{"type":"function","title":"Unicode.Property.other_grapheme_extend?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_grapheme_extend`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_grapheme_extend`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_grapheme_extend?/1"},{"type":"function","title":"Unicode.Property.other_id_continue/1","doc":"Returns `:other_id_continue` or `nil` indicating\nif the codepoint or string has the property\n`:other_id_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_id_continue`\nproperty in order for the result to `:other_id_continue`.","ref":"Unicode.Property.html#other_id_continue/1"},{"type":"function","title":"Unicode.Property.other_id_continue?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_id_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_id_continue`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_id_continue?/1"},{"type":"function","title":"Unicode.Property.other_id_start/1","doc":"Returns `:other_id_start` or `nil` indicating\nif the codepoint or string has the property\n`:other_id_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_id_start`\nproperty in order for the result to `:other_id_start`.","ref":"Unicode.Property.html#other_id_start/1"},{"type":"function","title":"Unicode.Property.other_id_start?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_id_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_id_start`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_id_start?/1"},{"type":"function","title":"Unicode.Property.other_lowercase/1","doc":"Returns `:other_lowercase` or `nil` indicating\nif the codepoint or string has the property\n`:other_lowercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_lowercase`\nproperty in order for the result to `:other_lowercase`.","ref":"Unicode.Property.html#other_lowercase/1"},{"type":"function","title":"Unicode.Property.other_lowercase?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_lowercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_lowercase`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_lowercase?/1"},{"type":"function","title":"Unicode.Property.other_math/1","doc":"Returns `:other_math` or `nil` indicating\nif the codepoint or string has the property\n`:other_math`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_math`\nproperty in order for the result to `:other_math`.","ref":"Unicode.Property.html#other_math/1"},{"type":"function","title":"Unicode.Property.other_math?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_math`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_math`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_math?/1"},{"type":"function","title":"Unicode.Property.other_uppercase/1","doc":"Returns `:other_uppercase` or `nil` indicating\nif the codepoint or string has the property\n`:other_uppercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_uppercase`\nproperty in order for the result to `:other_uppercase`.","ref":"Unicode.Property.html#other_uppercase/1"},{"type":"function","title":"Unicode.Property.other_uppercase?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:other_uppercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:other_uppercase`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#other_uppercase?/1"},{"type":"function","title":"Unicode.Property.pattern_syntax/1","doc":"Returns `:pattern_syntax` or `nil` indicating\nif the codepoint or string has the property\n`:pattern_syntax`.\n\nFor string parameters, all codepoints in\nthe string must have the `:pattern_syntax`\nproperty in order for the result to `:pattern_syntax`.","ref":"Unicode.Property.html#pattern_syntax/1"},{"type":"function","title":"Unicode.Property.pattern_syntax?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:pattern_syntax`.\n\nFor string parameters, all codepoints in\nthe string must have the `:pattern_syntax`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#pattern_syntax?/1"},{"type":"function","title":"Unicode.Property.pattern_white_space/1","doc":"Returns `:pattern_white_space` or `nil` indicating\nif the codepoint or string has the property\n`:pattern_white_space`.\n\nFor string parameters, all codepoints in\nthe string must have the `:pattern_white_space`\nproperty in order for the result to `:pattern_white_space`.","ref":"Unicode.Property.html#pattern_white_space/1"},{"type":"function","title":"Unicode.Property.pattern_white_space?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:pattern_white_space`.\n\nFor string parameters, all codepoints in\nthe string must have the `:pattern_white_space`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#pattern_white_space?/1"},{"type":"function","title":"Unicode.Property.prepended_concatenation_mark/1","doc":"Returns `:prepended_concatenation_mark` or `nil` indicating\nif the codepoint or string has the property\n`:prepended_concatenation_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:prepended_concatenation_mark`\nproperty in order for the result to `:prepended_concatenation_mark`.","ref":"Unicode.Property.html#prepended_concatenation_mark/1"},{"type":"function","title":"Unicode.Property.prepended_concatenation_mark?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:prepended_concatenation_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:prepended_concatenation_mark`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#prepended_concatenation_mark?/1"},{"type":"function","title":"Unicode.Property.properties/0","doc":"Returns the map of Unicode\nproperties.\n\nThe property name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.Property.html#properties/0"},{"type":"function","title":"Unicode.Property.properties/1","doc":"Returns the property name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nlist of properties for that codepoint name is returned.\n\nFor a binary a list of list for each\ncodepoint in the binary is returned.","ref":"Unicode.Property.html#properties/1"},{"type":"function","title":"Unicode.Property.quotation_mark/1","doc":"Returns `:quotation_mark` or `nil` indicating\nif the codepoint or string has the property\n`:quotation_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:quotation_mark`\nproperty in order for the result to `:quotation_mark`.","ref":"Unicode.Property.html#quotation_mark/1"},{"type":"function","title":"Unicode.Property.quotation_mark?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:quotation_mark`.\n\nFor string parameters, all codepoints in\nthe string must have the `:quotation_mark`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#quotation_mark?/1"},{"type":"function","title":"Unicode.Property.radical/1","doc":"Returns `:radical` or `nil` indicating\nif the codepoint or string has the property\n`:radical`.\n\nFor string parameters, all codepoints in\nthe string must have the `:radical`\nproperty in order for the result to `:radical`.","ref":"Unicode.Property.html#radical/1"},{"type":"function","title":"Unicode.Property.radical?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:radical`.\n\nFor string parameters, all codepoints in\nthe string must have the `:radical`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#radical?/1"},{"type":"function","title":"Unicode.Property.regional_indicator/1","doc":"Returns `:regional_indicator` or `nil` indicating\nif the codepoint or string has the property\n`:regional_indicator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:regional_indicator`\nproperty in order for the result to `:regional_indicator`.","ref":"Unicode.Property.html#regional_indicator/1"},{"type":"function","title":"Unicode.Property.regional_indicator?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:regional_indicator`.\n\nFor string parameters, all codepoints in\nthe string must have the `:regional_indicator`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#regional_indicator?/1"},{"type":"function","title":"Unicode.Property.sentence_terminal/1","doc":"Returns `:sentence_terminal` or `nil` indicating\nif the codepoint or string has the property\n`:sentence_terminal`.\n\nFor string parameters, all codepoints in\nthe string must have the `:sentence_terminal`\nproperty in order for the result to `:sentence_terminal`.","ref":"Unicode.Property.html#sentence_terminal/1"},{"type":"function","title":"Unicode.Property.sentence_terminal?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:sentence_terminal`.\n\nFor string parameters, all codepoints in\nthe string must have the `:sentence_terminal`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#sentence_terminal?/1"},{"type":"function","title":"Unicode.Property.servers/0","doc":"Returns a map of properties to the module\nthat serves that property.","ref":"Unicode.Property.html#servers/0"},{"type":"function","title":"Unicode.Property.soft_dotted/1","doc":"Returns `:soft_dotted` or `nil` indicating\nif the codepoint or string has the property\n`:soft_dotted`.\n\nFor string parameters, all codepoints in\nthe string must have the `:soft_dotted`\nproperty in order for the result to `:soft_dotted`.","ref":"Unicode.Property.html#soft_dotted/1"},{"type":"function","title":"Unicode.Property.soft_dotted?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:soft_dotted`.\n\nFor string parameters, all codepoints in\nthe string must have the `:soft_dotted`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#soft_dotted?/1"},{"type":"function","title":"Unicode.Property.terminal_punctuation/1","doc":"Returns `:terminal_punctuation` or `nil` indicating\nif the codepoint or string has the property\n`:terminal_punctuation`.\n\nFor string parameters, all codepoints in\nthe string must have the `:terminal_punctuation`\nproperty in order for the result to `:terminal_punctuation`.","ref":"Unicode.Property.html#terminal_punctuation/1"},{"type":"function","title":"Unicode.Property.terminal_punctuation?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:terminal_punctuation`.\n\nFor string parameters, all codepoints in\nthe string must have the `:terminal_punctuation`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#terminal_punctuation?/1"},{"type":"function","title":"Unicode.Property.unified_ideograph/1","doc":"Returns `:unified_ideograph` or `nil` indicating\nif the codepoint or string has the property\n`:unified_ideograph`.\n\nFor string parameters, all codepoints in\nthe string must have the `:unified_ideograph`\nproperty in order for the result to `:unified_ideograph`.","ref":"Unicode.Property.html#unified_ideograph/1"},{"type":"function","title":"Unicode.Property.unified_ideograph?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:unified_ideograph`.\n\nFor string parameters, all codepoints in\nthe string must have the `:unified_ideograph`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#unified_ideograph?/1"},{"type":"function","title":"Unicode.Property.uppercase/1","doc":"Returns `:uppercase` or `nil` indicating\nif the codepoint or string has the property\n`:uppercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:uppercase`\nproperty in order for the result to `:uppercase`.","ref":"Unicode.Property.html#uppercase/1"},{"type":"function","title":"Unicode.Property.uppercase?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:uppercase`.\n\nFor string parameters, all codepoints in\nthe string must have the `:uppercase`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#uppercase?/1"},{"type":"function","title":"Unicode.Property.variation_selector/1","doc":"Returns `:variation_selector` or `nil` indicating\nif the codepoint or string has the property\n`:variation_selector`.\n\nFor string parameters, all codepoints in\nthe string must have the `:variation_selector`\nproperty in order for the result to `:variation_selector`.","ref":"Unicode.Property.html#variation_selector/1"},{"type":"function","title":"Unicode.Property.variation_selector?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:variation_selector`.\n\nFor string parameters, all codepoints in\nthe string must have the `:variation_selector`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#variation_selector?/1"},{"type":"function","title":"Unicode.Property.white_space/1","doc":"Returns `:white_space` or `nil` indicating\nif the codepoint or string has the property\n`:white_space`.\n\nFor string parameters, all codepoints in\nthe string must have the `:white_space`\nproperty in order for the result to `:white_space`.","ref":"Unicode.Property.html#white_space/1"},{"type":"function","title":"Unicode.Property.white_space?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:white_space`.\n\nFor string parameters, all codepoints in\nthe string must have the `:white_space`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#white_space?/1"},{"type":"function","title":"Unicode.Property.xid_continue/1","doc":"Returns `:xid_continue` or `nil` indicating\nif the codepoint or string has the property\n`:xid_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:xid_continue`\nproperty in order for the result to `:xid_continue`.","ref":"Unicode.Property.html#xid_continue/1"},{"type":"function","title":"Unicode.Property.xid_continue?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:xid_continue`.\n\nFor string parameters, all codepoints in\nthe string must have the `:xid_continue`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#xid_continue?/1"},{"type":"function","title":"Unicode.Property.xid_start/1","doc":"Returns `:xid_start` or `nil` indicating\nif the codepoint or string has the property\n`:xid_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:xid_start`\nproperty in order for the result to `:xid_start`.","ref":"Unicode.Property.html#xid_start/1"},{"type":"function","title":"Unicode.Property.xid_start?/1","doc":"Returns a boolean indicating if the\ncodepoint or string has the property\n`:xid_start`.\n\nFor string parameters, all codepoints in\nthe string must have the `:xid_start`\nproperty in order for the result to be `true`.","ref":"Unicode.Property.html#xid_start?/1"},{"type":"type","title":"Unicode.Property.string_or_codepoint/0","doc":"","ref":"Unicode.Property.html#t:string_or_codepoint/0"},{"type":"module","title":"Unicode.Script","doc":"Property manager for the Unicode script property.","ref":"Unicode.Script.html"},{"type":"function","title":"Unicode.Script.aliases/0","doc":"Returns a map of aliases for\nUnicode scripts.\n\nAn alias is an alternative name\nfor referring to a script. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.Script.html#aliases/0"},{"type":"function","title":"Unicode.Script.count/1","doc":"Returns the count of the number of characters\nfor a given script.","ref":"Unicode.Script.html#count/1"},{"type":"function","title":"Example - Unicode.Script.count/1","doc":"iex> Unicode.Script.count(\"mongolian\")\n    168","ref":"Unicode.Script.html#count/1-example"},{"type":"function","title":"Unicode.Script.fetch/1","doc":"Returns the Unicode ranges for\na given script as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.Script.html#fetch/1"},{"type":"function","title":"Unicode.Script.get/1","doc":"Returns the Unicode ranges for\na given script as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.Script.html#get/1"},{"type":"function","title":"Unicode.Script.known_scripts/0","doc":"Returns a list of known Unicode\nscript names.\n\nThis function does not return the\nnames of any script aliases.","ref":"Unicode.Script.html#known_scripts/0"},{"type":"function","title":"Unicode.Script.script/1","doc":"Returns the script name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nscript name is returned.\n\nFor a binary a list of distinct script\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.Script.html#script/1"},{"type":"function","title":"Unicode.Script.scripts/0","doc":"Returns the map of Unicode\nscripts.\n\nThe script name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.Script.html#scripts/0"},{"type":"module","title":"Unicode.SentenceBreak","doc":"Functions to introspect Unicode\nsentence breaks for binaries\n(Strings) and codepoints.","ref":"Unicode.SentenceBreak.html"},{"type":"function","title":"Unicode.SentenceBreak.aliases/0","doc":"Returns a map of aliases for\nUnicode sentence breaks.\n\nAn alias is an alternative name\nfor referring to a sentence break. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.SentenceBreak.html#aliases/0"},{"type":"function","title":"Unicode.SentenceBreak.count/1","doc":"Returns the count of the number of characters\nfor a given sentence break.","ref":"Unicode.SentenceBreak.html#count/1"},{"type":"function","title":"Example - Unicode.SentenceBreak.count/1","doc":"iex> Unicode.SentenceBreak.count(:extend)\n    2601","ref":"Unicode.SentenceBreak.html#count/1-example"},{"type":"function","title":"Unicode.SentenceBreak.fetch/1","doc":"Returns the Unicode ranges for\na given sentence break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.SentenceBreak.html#fetch/1"},{"type":"function","title":"Unicode.SentenceBreak.get/1","doc":"Returns the Unicode ranges for\na given sentence break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.SentenceBreak.html#get/1"},{"type":"function","title":"Unicode.SentenceBreak.known_sentence_breaks/0","doc":"Returns a list of known Unicode\nsentence break names.\n\nThis function does not return the\nnames of any sentence break aliases.","ref":"Unicode.SentenceBreak.html#known_sentence_breaks/0"},{"type":"function","title":"Unicode.SentenceBreak.sentence_break/1","doc":"Returns the sentence break name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nsentence break name is returned.\n\nFor a binary a list of distinct sentence break\nnames represented by the graphemes in\nthe binary is returned.","ref":"Unicode.SentenceBreak.html#sentence_break/1"},{"type":"function","title":"Unicode.SentenceBreak.sentence_breaks/0","doc":"Returns the map of Unicode\nsentence breaks.\n\nThe sentence break name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.SentenceBreak.html#sentence_breaks/0"},{"type":"module","title":"Unicode.WordBreak","doc":"Functions to introspect Unicode word breaks for\nstring and codepoints.","ref":"Unicode.WordBreak.html"},{"type":"function","title":"Unicode.WordBreak.aliases/0","doc":"Returns a map of aliases for\nUnicode word breaks.\n\nAn alias is an alternative name\nfor referring to a word break. Aliases\nare resolved by the `fetch/1` and\n`get/1` functions.","ref":"Unicode.WordBreak.html#aliases/0"},{"type":"function","title":"Unicode.WordBreak.count/1","doc":"Returns the count of the number of characters\nfor a given word_break.","ref":"Unicode.WordBreak.html#count/1"},{"type":"function","title":"Example - Unicode.WordBreak.count/1","doc":"iex> Unicode.WordBreak.count(:al)\n    21400","ref":"Unicode.WordBreak.html#count/1-example"},{"type":"function","title":"Unicode.WordBreak.fetch/1","doc":"Returns the Unicode ranges for\na given word break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `{:ok, range_list}` or\n`:error`.","ref":"Unicode.WordBreak.html#fetch/1"},{"type":"function","title":"Unicode.WordBreak.get/1","doc":"Returns the Unicode ranges for\na given word break as a list of\nranges as 2-tuples.\n\nAliases are resolved by this function.\n\nReturns either `range_list` or\n`nil`.","ref":"Unicode.WordBreak.html#get/1"},{"type":"function","title":"Unicode.WordBreak.known_word_breaks/0","doc":"Returns a list of known Unicode\nword break names.\n\nThis function does not return the\nnames of any word break aliases.","ref":"Unicode.WordBreak.html#known_word_breaks/0"},{"type":"function","title":"Unicode.WordBreak.word_break/1","doc":"Returns the word break name(s) for the\ngiven binary or codepoint.\n\nIn the case of a codepoint, a single\nword_break name is returned.\n\nFor a binary a list of distinct word break\nnames represented by the lines in\nthe binary is returned.\n\nA value of `:xx` indicates there is no word\nbreak property for a codepoint.","ref":"Unicode.WordBreak.html#word_break/1"},{"type":"function","title":"Unicode.WordBreak.word_breaks/0","doc":"Returns the map of Unicode\nword breaks.\n\nThe word break name is the map\nkey and a list of codepoint\nranges as tuples as the value.","ref":"Unicode.WordBreak.html#word_breaks/0"},{"type":"extras","title":"Unicode","doc":"# Unicode\n\n![Build status](https://github.com/elixir-unicode/unicode/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/unicode.svg)](https://hex.pm/packages/unicode)\n[![Hex.pm](https://img.shields.io/hexpm/dw/unicode.svg?)](https://hex.pm/packages/unicode)\n[![Hex.pm](https://img.shields.io/hexpm/dt/unicode.svg?)](https://hex.pm/packages/unicode)\n[![Hex.pm](https://img.shields.io/hexpm/l/unicode.svg)](https://hex.pm/packages/unicode)\n\nFunctions to return information about Unicode codepoints.\n\nElixir strings are UTF-8-encoded [Unicode](https://unicode.org) binaries. This is a flexible and complete encoding scheme for the worlds many scripts, characters and emjois. However since it's a variable length encoding (using between one and four bytes for UTF-8) it is harder to use high-performance byte-oriented functions to decompose strings.\n\nSince checking strings and codepoints for certain attributes - like whether they are upper case, or symbols, or whitespace - is a common occurrence, a performant approach to such detection is useful.\n\nIt is tempting to assume the use of [US ASCII](https://en.wikipedia.org/wiki/ASCII) encoding and checking only for characters in that range. For example it is very common to see code in Elixir checking `codepoint in ?a..?z` to check for lowercase alphabetic characters. When the underlying programming language has no canonical form for a string beyond bytes this may be considered acceptable - the programmer is defining the script domain as he or she sees fit.\n\nHowever since Elixir strings are declared to be [UTF-8 encoded Unicode strings](https://unicode.org/faq/utf_bom.html#utf8-1) it seems appropriate to make it easier to determine the characteristics of codepoints (and strings) using this standard.\n\nThe Elixir standard library does not provide introspection beyond that required to support casing (String.downcase/1, String.upcase/1, String.capitalize/1).  This library aims to *fill in the blanks* a little bit.","ref":"readme.html"},{"type":"extras","title":"Unicode version - Unicode","doc":"As of [unicode version 1.20.0](https://hex.pm/packages/unicode/1.20.0) published on September 11th, 2024, [Unicode 16.0](https://www.unicode.org/versions/Unicode16.0.0/) forms the underlying data.","ref":"readme.html#unicode-version"},{"type":"extras","title":"Additional Unicode libraries - Unicode","doc":"[ex_unicode](https://hex.pm/packages/unicode) provides basic introspection of Unicode codepoints and strings.  Additional libraries (either released or in development) build upon this library):\n\n* [unicode_set](https://github.com/elixir-unicode/unicode_set) implements functions to parse and match on [unicode sets](http://unicode.org/reports/tr35/#Unicode_Sets)\n\n* [unicode_guards](https://github.com/elixir-unicode/unicode_guards) is a simple library implementing common function guards using `unicode_set` and `unicode`\n\n* [unicode_string](https://github.com/elixir-unicode/unicode_string) is a library to implement efficient string splitting into words and sentences based upon the [Unicode Segementation](https://unicode.org/reports/tr29/) algorithm.\n\n* [unicode_transform](https://github.com/elixir-unicode/unicode_transform) implements the [Unicode transform](https://unicode.org/reports/tr35/tr35-general.html#Transforms) specification.","ref":"readme.html#additional-unicode-libraries"},{"type":"extras","title":"Unicode Functions - Unicode","doc":"The following is a partial list of functions included in the library. See the documentation for the relevant module for further information:","ref":"readme.html#unicode-functions"},{"type":"extras","title":"Codepoint ranges - Unicode","doc":"These functions return the codepoints as list of 2-tuples for the given property:\n\n* `Unicode.Block.blocks/0`\n* `Unicode.Script.scripts/0`\n* `Unicode.GeneralCategory.categories/0`\n* `Unicode.CombiningClass.combining_classes/0`\n* `Unicode.GraphemeBreak.grapheme_breaks/0`\n* `Unicode.LineBreak.line_breaks/0`\n* `Unicode.SentenceBreak.sentence_breaks/0`\n* `Unicode.IndicSyllabicCategory.indic_syllabic_categories/0`\n* `Unicode.Property.properties/0`","ref":"readme.html#codepoint-ranges"},{"type":"extras","title":"Introspection of codepoints and strings - Unicode","doc":"The following functions return the block, script and category for codepoints and strings:\n\n*   `Unicode.script/1`\n\n    ```elixir\n    iex> Unicode.script ?ä\n    :latin\n\n    iex> Unicode.script ?خ\n    :arabic\n\n    iex> Unicode.script ?अ\n    :devanagari\n    ```\n\n*   `Unicode.block/1`\n\n    ```elixir\n    iex> Unicode.block ?ä\n    :latin_1_supplement\n\n    iex> Unicode.block ?A\n    :basic_latin\n\n    iex> Unicode.block \"äA\"\n    [:latin_1_supplement, :basic_latin]\n    ```\n\n*   `Unicode.category/1`\n\n    ```elixir\n    iex> Unicode.category ?ä\n    :Ll\n    iex> Unicode.category ?A\n    :Lu\n    iex> Unicode.category ?🧐\n    :So\n    ```\n\n*   `Unicode.properties/1`\n\n    ```elixir\n    iex> Unicode.properties 0x1bf0\n    [\n      :alphabetic,\n      :case_ignorable,\n      :grapheme_extend,\n      :id_continue,\n      :other_alphabetic,\n      :xid_continue\n    ]\n\n    iex> Unicode.properties ?A\n    [\n      :alphabetic,\n      :ascii_hex_digit,\n      :cased,\n      :changes_when_casefolded,\n      :changes_when_casemapped,\n      :changes_when_lowercased,\n      :grapheme_base,\n      :hex_digit,\n      :id_continue,\n      :id_start,\n      :uppercase,\n      :xid_continue,\n      :xid_start\n    ]\n\n    iex> Unicode.properties ?+\n    [:grapheme_base, :math, :pattern_syntax]\n\n    iex> Unicode.properties \"a1+\"\n    [\n      [\n        :alphabetic,\n        :ascii_hex_digit,\n        :cased,\n        :changes_when_casemapped,\n        :changes_when_titlecased,\n        :changes_when_uppercased,\n        :grapheme_base,\n        :hex_digit,\n        :id_continue,\n        :id_start,\n        :lowercase,\n        :xid_continue,\n        :xid_start\n      ],\n      [\n        :ascii_hex_digit,\n        :emoji,\n        :grapheme_base,\n        :hex_digit,\n        :id_continue,\n        :xid_continue\n      ],\n      [:grapheme_base, :math, :pattern_syntax]\n    ]\n    ```","ref":"readme.html#introspection-of-codepoints-and-strings"},{"type":"extras","title":"Character classes - Unicode","doc":"These functions help filter codepoints and strings based upon their properties. They return a boolean result.\n\n* `Unicode.alphabetic?/1`\n* `Unicode.alphanumeric?/1`\n* `Unicode.digits?/1`\n* `Unicode.numeric?/1`\n* `Unicode.emoji?/1`\n* `Unicode.math?/1`\n* `Unicode.cased?/1`\n* `Unicode.lowercase?/1`\n* `Unicode.uppercase?/1`\n\nAny known property can be called as a function `Unicode.Property. (codepoint_or_string)` or `Unicode.Property. ?(codepoint_or_string)` to return a boolean.","ref":"readme.html#character-classes"},{"type":"extras","title":"Transformations - Unicode","doc":"The function `Unicode.unaccent/1` attempts to transform a Unicode string into a subset of the Latin-1 alphabet by removing diacritical marks from text. It is not a full transformation (which will be available in the upcoming `unicode_transform` library.)","ref":"readme.html#transformations"},{"type":"extras","title":"Recognition - Unicode","doc":"The information functions are heavily inspired by [@qqwy's elixir-unicode package](https://github.com/Qqwy/elixir-unicode) and compatibility with some of the api is represented by including some of the doctests from that package. Originally published under the `:unicode` package name on hex, this original work is now replaced with this library code.","ref":"readme.html#recognition"},{"type":"extras","title":"Installation - Unicode","doc":"The package can be installed by adding `unicode` to your list of dependencies in `mix.exs`:\n\n<!-- BEGIN: VERSION -->\n```elixir\ndef deps do\n  [\n    {:unicode, \"~> 1.20\"}\n  ]\nend\n```\n<!-- END: VERSION -->\n\nThe docs can be found at [https://hexdocs.pm/unicode](https://hexdocs.pm/unicode).","ref":"readme.html#installation"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2018 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unicode v1.20.0 - Changelog","doc":"This is the changelog for Unicode v1.20.0 released on September 11, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-20-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [Unicode 16.0](https://unicode.org/versions/Unicode16.0.0/) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.19.0 - Changelog","doc":"This is the changelog for Unicode v1.19.0 released on February 29th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-19-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Unicode.properties/1` no longer does an `Enum.uniq/1` on the result since that breaks the functions contract.\n\n* Fix `Unicode.Emoji.emoji/0`.\n\n* Fix documentation in `Unicode.WordBreak`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `indic_conjunc_break` as a property, it is new in Unicode 15.1.\n\n* Fix performance regression in `Unicode.replace_invalid/2` from the original UniRecover library and confirm the code memory usage remains a constant 128 bytes for all benchmark scenarios. Thanks to @Moosieus for the fabulous PR. Closes #10.\n\n* `Unicode.replace_invalid(string, :utf8, replacement)` delegates to `String.replace_invalid/2` where available (which will be from Elixir 1.16 onwards).\n\n* Confirm that the README installation version matches the code version. Thanks to @Moosieus for the PR.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.18.0 - Changelog","doc":"This is the changelog for Unicode v1.18.0 released on October 19th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-18-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Unicode.replace_invalid/3` to force-validate a binary as a UTF string. Any of the UTF encodings may be validated. Any invalid codepoints or incomplete sequences are replaced with a replacement string.  Many thanks to @Moosieus for the contribution.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.17.0 - Changelog","doc":"This is the changelog for Unicode v1.17.0 released on September 17th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-17-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [Unicode 15.1](https://unicode.org/versions/Unicode15.1.0/) data.\n\n* Improve the security of the `mix unicode.download` task.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.16.2 - Changelog","doc":"This is the changelog for Unicode v1.16.2 released on August 16th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-16-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Change the parsing of \"SpecialCasing.text\" specifically to support casing in [unicode_string](https://hex.pm/packages/unicode_string)/.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.16.1 - Changelog","doc":"This is the changelog for Unicode v1.16.1 released on April 22nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-16-1"},{"type":"extras","title":"Big Fixes - Changelog","doc":"* Fix spelling of `Unicode.script_dominance/1`.","ref":"changelog.html#big-fixes"},{"type":"extras","title":"Unicode v1.16.0 - Changelog","doc":"This is the changelog for Unicode v1.16.0 released on March 18th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-16-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Unicode.script_statistic/1` that returns the first index and grapheme count of the scripts in a string. This is useful to help derive the likely locale of a string. Determining the locale is outside the scope of this library but is required in [ex_cldr_person_names](https://hex.pm/packages/ex_cldr_person_names).\n\n* Add `Unicode.script_dominance/1` to sort the results of `Unicode.script_statistic/1` in descending dominance order.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.15.0 - Changelog","doc":"This is the changelog for Unicode v1.15.0 released on September 17th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)\n\nNote there is no release 1.14.  The release is 1.15 to align with Unicode 15 and it is expected to keep this pattern into the future.","ref":"changelog.html#unicode-v1-15-0"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Fix deprecation warnings for Elixir 1.14.  Now requires Elixir 1.11 as a minimum release.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [Unicode 15](https://www.unicode.org/versions/Unicode15.0.0/).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix code fences in docs to be Elixir","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.13.1 - Changelog","doc":"This is the changelog for Unicode v1.13.1 released on September 16th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-13-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* When looking up scripts, general categories and properties we indirect through an alias table. But not all entries have alias so in the case alias lookup fails we still need to lookup using the original key.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.13.0 - Changelog","doc":"This is the changelog for Unicode v1.13.0 released on September 15th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-13-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Change the application name to `:unicode` (in collaboration with @Qqwy). The old name `ex_unicode` will be retired.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.12.0 - Changelog","doc":"This is the changelog for Unicode v1.12.0 released on September 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to use [Unicode 14](https://unicode.org/versions/Unicode14.0.0) release data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.12.0-rc.0 - Changelog","doc":"This is the changelog for Unicode v1.12.0-rc.0 released on August 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-12-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to Unicode 14 preview data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.11.2 - Changelog","doc":"This is the changelog for Unicode v1.11.2 released on May 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-11-2"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Make `ex_doc` and `benchee` optional. Thanks to @fireproofsocks.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.11.1 - Changelog","doc":"This is the changelog for Unicode v1.11.1 released on January 5th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-11-1"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Restrict `ex_doc` to only `:dev` and `:release`. Closes #3. Thanks to @manuelmontenegro.\n\n* Fix spec for `Unicode.all/0` so dialyzer is happy","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.11.0 - Changelog","doc":"This is the changelog for Unicode v1.11.0 released on October 8th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-11-0"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Rename the derived category `:visible` to `:graph` and change the definition to that in [Unicode Regular Expressions](http://unicode.org/reports/tr18/). Deprecate the derived category `:visible`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.10.0 - Changelog","doc":"This is the changelog for Unicode v1.10.0 released on October 5th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-10-0"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Revert \"Change the definition of the derived property `All` to be the disjoint set of unicode ranges, not the closed set.\" since `All` in the ICU means the full range of codepoints, assigned or otherwise.\n\n* Add `:inets` and `:public_key` to `:extra_applicatons` to avoid warnings on Elixir 1.11.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Unicode.assigned/0` to return the list of codepoint ranges that are assigned within Unicode\n\n* Rename `Unicode.ranges/0` to `Unicode.all/0` to better reflect the intent. `Unicode.ranges/0` is deprecated.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.9.0 - Changelog","doc":"This is the changelog for Unicode v1.9.0 released on October 4th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Change the definition of the derived property `All` to be the disjoint set of unicode ranges, not the closed set.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.8.0 - Changelog","doc":"This is the changelog for Unicode v1.8.0 released on July 12th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add the east asian width property to `Unicode.Property.fetch/2` API\n\n* Add the word break property to `Unicode.Property.fetch/2` API","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.7.0 - Changelog","doc":"This is the changelog for Unicode v1.7.0 released on June 22nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add the emoji properties to `Uniccode.Property.fetch/2` API\n\n* Add certificate verification to download process","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.6.0 - Changelog","doc":"This is the changelog for Unicode v1.6.0 released on May 17th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Unicode.Utils.case_folding/0`\n\n* Add `Unicode.Utils.special_casing/0`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.5.0 - Changelog","doc":"This is the changelog for Unicode v1.5.0 released on March 14th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add derived categories `:printable:` and `:visible:`. `:printable:` implements the same semnantics `String.printable?/1`. `:visible:` combines the categories `[[:L:][:N:][:M:][:P:][:S:][:Zs:]]`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.4.1 - Changelog","doc":"This is the changelog for Unicode v1.4.1 released on March 11th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-4-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Regenerate the assigned ranges for Unicode 13","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.4.0 - Changelog","doc":"This is the changelog for Unicode v1.4.0 released on March 11th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"#### Updates Unicode to version 13.0.\n\nAs of March 2020, Unicode has introduced [Unicode 13.0](http://blog.unicode.org/2020/03/announcing-unicode-standard-version-130.html) and this data now forms the basis of `ex_unicode` version 1.40. Version 13 of Unicode adds 5,390 characters, for a total of 143,859 characters. These additions include four new scripts, for a total of 154 scripts, as well as 55 new emoji characters.\n\n#### Adds derived categories for various quotation marks.\n\nAlthough the unicode character database has a flag to indicate if a given codepoint is a quotation mark, the list does not include CJK quotation marks, dingbats or alternative encodings. Some additional derived categories are therefore added that are taken from [Wikipedia](https://en.wikipedia.org/wiki/Quotation_mark). The added dervived categories are:\n\n  * QuoteMark - all quote marks\n  * QuoteMarkLeft - all quote marks used on the left\n  * QuoteMarkRight - quote marks used on the right\n  * QuoteMarkAmbidextrous - quote marks used either left or right\n  * QuoteMarkSingle - single quote marks\n  * QuoteMarkDouble - double quote marks\n\nThese additional derived categories can be used in [Unicode Sets](https://hex.pm/packages/unicode_sets), for example:\n\n```elixir\niex> Unicode.Set.match? ?', \"[[:quote_mark:]]\"\ntrue\niex> Unicode.Set.match? ?', \"[[:quote_mark_left:]]\"\nfalse\niex> Unicode.Set.match? ?', \"[[:quote_mark_ambidextrous:]]\"\ntrue\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.3.1 - Changelog","doc":"This is the changelog for Unicode v1.3.1 released on January 8th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-3-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove call to `Code.ensure_compiled?/1` which is deprecated in Elixir 1.10.0.\n\n* Fix the ranges for the General Category `:assigned`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.3.0 - Changelog","doc":"This is the changelog for Unicode v1.3.0 released on December 3rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-3-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Changed two module names: `Unicode.Category` becomes `Unicode.GeneralCategory` and `Unicode.CombiningClass` becomes `Unicode.CanonicalCombiningClass`. These names map directly to the Unicode standard names. It also means all property module names can be derived from the Unicode property name which is what the new `Unicode.servers/0` function does.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add property modules for line break, sentence break, grapheme cluster break and indic syllabic category. These properties are used by the CLDR and Unicode segmentation rules.\n\n* Add `Unicode.servers/0` that maps property names and aliases to a module name that serves that property.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes `Unicode.aliases/0` to correctly use the aliases in `data/property_alias.txt`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode v1.2.0 - Changelog","doc":"This is the changelog for Unicode v1.2.0 released on November 27th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-2-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Script names are now atoms instead of strings to be consistent with other properties","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `aliases/0`, `fetch/1` and `get/1` to `Unicode.Property`\n\n* Added additional properties to `Unicode.Property`. The set now includes those from the UCD files `DerivedCoreProperties.txt` and `PropList.txt`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.1.0 - Changelog","doc":"This is the changelog for Unicode v1.1.0 released on November 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-1-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Removed `Unicode.Guards` from this library and moved them to the [unicode_set](https://hex.pm/packages/unicode_guards) package.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `Unicode.Category.categories/0` now returns the super categories as well as the subcategories. These super categories are computed at compile time by consolidating the relevant subcategories. `Unicode.Category.category/1` will only return one category, and it will be the subcategory as it consistent with earlier releases.\n\n* Add `Unicode.ranges/0` that returns all Unicode codepoints as a list of 2-tuples representing the disjoint ranges of valid codepoints. The list is in sorted order.\n\n* Add `aliases/0` for `Unicode.Category`, `Unicode.Script`, `Unicode.Block`, and `Unicode.CombiningClass` which returns the alias map for the relevant module.\n\n* Add `fetch/1` and `get/1` for `Unicode.Category`, `Unicode.Script`, `Unicode.Block`, and `Unicode.CombiningClass`. These functions leverage Unicode property value aliases for retrieving codepoints.\n\n* Add `Unicode.fetch_property/1` and `Unicode.get_property/1` that return the module responsible for handling a given Unicode property.\n\n* Add `Unicode.compact_ranges/1` that given a list of 2-tuple ranges will compact them into as small a list of contiguous blocks as possible\n\n* Documented all public functions","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode v1.0.0 - Changelog","doc":"This is the changelog for Unicode v1.0.0 released on November 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode/tags)","ref":"changelog.html#unicode-v1-0-0"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Rename the module prefix to `Unicode` since this package is not linked in any way to the `Cldr` family. The hex package is renamed to `ex_unicode`.","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Cldr Unicode v0.7.1 - Changelog","doc":"This is the changelog for Unicode v0.7.1 released on November 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `count/1` for blocks, scripts and categories\n\n* Replace deprecated `String.normalize/2` with `:unicode.characters_to_nfd_binary/` for OTP release 20 and later.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr Unicode v0.7.0 - Changelog","doc":"This is the changelog for Unicode v0.7.0 released on November 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `is_whitespace/1` guard generator","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Unicode v0.6.0 - Changelog","doc":"This is the changelog for Unicode v0.6.0 released on October 22nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to Emoji 12.1","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Unicode v0.5.0 - Changelog","doc":"This is the changelog for Unicode v0.5.0 released on May 12th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to Unicode 12.1","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Unicode v0.4.0 - Changelog","doc":"This is the changelog for Unicode v0.4.0 released on April 30th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Unicode.unaccent/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Block names are now atoms instead of strings","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Cldr Unicode v0.3.0 - Changelog","doc":"This is the changelog for Unicode v0.3.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to Unicode version 12","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Unicode v0.2.0 - Changelog","doc":"This is the changelog for Unicode v0.2.0 released on February 24th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Moves the public API to the `Cldr.Unicode` module.\n\n* Updates and adds documentation to all public functions.\n\n* Removes the text annotations from the compiled functions which materially reduces the size of the beam files.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr Unicode v0.1.0 - Changelog","doc":"This is the changelog for Unicode v0.1.0 released on February 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr_unicode/tags)","ref":"changelog.html#cldr-unicode-v0-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release","ref":"changelog.html#enhancements"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}